@@ -1,4 +1,4 @@
-/* 
+/*
  *	HT Editor
  *	analy.cc
  *
@@ -36,9 +36,9 @@
 #include "snprintf.h"
 #include "tools.h"
 
+#define DPRINTF(msg...)
 //#undef DPRINTF
 //#define DPRINTF(msg...) {global_analyser_address_string_format = ADDRESS_STRING_FORMAT_LEADING_ZEROS;char buf[1024]; ht_snprintf(buf, sizeof buf, ##msg); fprintf(stdout, buf);}
-#define DPRINTF(msg...)
 
 int global_analyser_address_string_format = ADDRESS_STRING_FORMAT_COMPACT;
 
@@ -479,7 +479,7 @@ void CommentList::appendPostComment(int special)
 
 const char *CommentList::getName(UINT i)
 {
-	ht_data *d = get(i);
+	Object *d = get(i);
 	return d ? ((d->object_id()==ATOM_HT_DATA_UINT) ? comment_lookup(((ht_data_uint*)d)->value): ((ht_data_string*)d)->value) : NULL;
 }
 
@@ -657,6 +657,7 @@ int Analyser::load(ht_object_stream *st)
 
 	if (st->get_error()) return st->get_error();
 
+//	st->getObject((Object*)analy_disasm, "analy_disasm");
 	GET_OBJECT(st, analy_disasm);
 	GET_OBJECT(st, disasm);     
 	if (analy_disasm) {
