@@ -2,7 +2,7 @@
  *	HT Editor
  *	analy_alpha.h
  *
- *	Copyright (C) 1999, 2000, 2001 Sebastian Biallas (sb@web-productions.de)
+ *	Copyright (C) 1999-2002 Sebastian Biallas (sb@web-productions.de)
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -24,16 +24,17 @@
 #include "analy.h"
 #include "alphadis.h"
 
-class analy_alpha_disassembler: public analy_disassembler {
+class AnalyAlphaDisassembler: public AnalyDisassembler {
 public:
-			void			init(analyser *A);
+			void			init(Analyser *A);
 			int 			load(ht_object_stream *f);
 	virtual   void	     	done();
-	virtual	OBJECT_ID		object_id();
+	virtual	OBJECT_ID		object_id() const;
 
-	virtual	ADDR			branch_addr(OPCODE *opcode);
-	virtual	void			init_disasm();
-	virtual	tbranchtype 	is_branch(OPCODE *opcode);
+	virtual	Address		*branchAddr(OPCODE *opcode, branch_enum_t branchtype, bool examine);
+			Address		*createAddress(dword offset);
+	virtual	void			examineOpcode(OPCODE *opcode);
+	virtual	branch_enum_t 	isBranch(OPCODE *opcode);
 	virtual	void			store(ht_object_stream *f);
 };
 
