@@ -104,11 +104,11 @@ char *label_prefix(const char *p)
 bool valid_name(const char *str)
 {
 	if ((!str) || (!*str)) return false;
-	char mc = mapchar[*str];
+	char mc = mapchar[(unsigned char)*str];
 	if ((mc == '_') || (mc == '?') || (mc == 'A') || (mc == '@')) {
 		str++;
 		while (*str) {
-			mc = mapchar[*str];
+			mc = mapchar[(unsigned char)*str];
 			if ((mc == '_') || (mc == '?') || (mc == 'A') || (mc == '0') || (mc == ':') || (mc == '.') || (mc == '@')) {
 				str++;
 			} else return false;
@@ -126,13 +126,13 @@ void make_valid_name(char *result, const char *str)
 		*result = '\0';
 		return;
 	}
-	char mc = mapchar[*str];
+	char mc = mapchar[(unsigned char)*str];
 	if (!((mc == '_') || (mc == '?') || (mc == 'A') || (mc == '@'))) {
 		*result++ = '_';
 		str++;
 	}
 	while (*str) {
-		mc = mapchar[*str];
+		mc = mapchar[(unsigned char)*str];
 		if ((mc == '_') || (mc == '?') || (mc == 'A') || (mc == '0') || (mc == ':') || (mc == '.') || (mc == '@')) {
 			*result++ = *str;
 		} else {
