@@ -26,15 +26,20 @@
 #include "analy_java.h"
 #include "analy_ia64.h"
 #include "analy_il.h"
+#include "analy_ppc.h"
 #include "analy_x86.h"
 #include "class_analy.h"
 #include "code_analy.h"
 #include "coff_analy.h"
 #include "data_analy.h"
 #include "elf_analy.h"
+#include "flt_analy.h"
 #include "ne_analy.h"
 #include "pe_analy.h"
 #include "le_analy.h"
+#include "macho_analy.h"
+#include "xbe_analy.h"
+#include "pef_analy.h"
 
 #include "htatom.h"
 
@@ -43,6 +48,7 @@ BUILDER(ATOM_ANALY_X86, AnalyX86Disassembler)
 BUILDER(ATOM_ANALY_IA64, AnalyIA64Disassembler)
 BUILDER(ATOM_ANALY_IL, AnalyILDisassembler)
 BUILDER(ATOM_ANALY_JAVA, AnalyJavaDisassembler)
+BUILDER(ATOM_ANALY_PPC, AnalyPPCDisassembler)
 
 BUILDER(ATOM_CODE_ANALYSER, CodeAnalyser)
 BUILDER(ATOM_DATA_ANALYSER, DataAnalyser)
@@ -55,6 +61,10 @@ BUILDER(ATOM_COFF_ANALYSER, CoffAnalyser)
 BUILDER(ATOM_NE_ANALYSER, NEAnalyser)
 BUILDER(ATOM_CLASS_ANALYSER, ClassAnalyser)
 BUILDER(ATOM_LE_ANALYSER, LEAnalyser)
+BUILDER(ATOM_MACHO_ANALYSER, MachoAnalyser)
+BUILDER(ATOM_FLT_ANALYSER, FLTAnalyser)
+BUILDER(ATOM_XBE_ANALYSER, XBEAnalyser)
+BUILDER(ATOM_PEF_ANALYSER, PEFAnalyser)
 
 BUILDER(ATOM_ADDRESS_INVALID, InvalidAddress)
 BUILDER(ATOM_ADDRESS_FLAT_32, AddressFlat32)
@@ -70,6 +80,7 @@ bool init_analyser()
 	REGISTER(ATOM_ANALY_IA64, AnalyIA64Disassembler)
 	REGISTER(ATOM_ANALY_IL, AnalyILDisassembler)
 	REGISTER(ATOM_ANALY_JAVA, AnalyJavaDisassembler)
+	REGISTER(ATOM_ANALY_PPC, AnalyPPCDisassembler)
 
 	REGISTER(ATOM_CODE_ANALYSER, CodeAnalyser)
 	REGISTER(ATOM_DATA_ANALYSER, DataAnalyser)
@@ -82,6 +93,10 @@ bool init_analyser()
 	REGISTER(ATOM_NE_ANALYSER, NEAnalyser)
 	REGISTER(ATOM_CLASS_ANALYSER, ClassAnalyser)
 	REGISTER(ATOM_LE_ANALYSER, LEAnalyser)
+	REGISTER(ATOM_MACHO_ANALYSER, MachoAnalyser)
+	REGISTER(ATOM_FLT_ANALYSER, FLTAnalyser)
+	REGISTER(ATOM_XBE_ANALYSER, XBEAnalyser)
+	REGISTER(ATOM_PEF_ANALYSER, PEFAnalyser)
 
 	REGISTER(ATOM_ADDRESS_INVALID, InvalidAddress)
 	REGISTER(ATOM_ADDRESS_FLAT_32, AddressFlat32)
@@ -99,6 +114,7 @@ void done_analyser()
 	UNREGISTER(ATOM_ANALY_IA64, AnalyIA64Disassembler)
 	UNREGISTER(ATOM_ANALY_IL, AnalyILDisassembler)
 	UNREGISTER(ATOM_ANALY_JAVA, AnalyJavaDisassembler)
+	UNREGISTER(ATOM_ANALY_PPC, AnalyPPCDisassembler)
 
 	UNREGISTER(ATOM_CODE_ANALYSER, CodeAnalyser)
 	UNREGISTER(ATOM_DATA_ANALYSER, DataAnalyser)
@@ -111,6 +127,10 @@ void done_analyser()
 	UNREGISTER(ATOM_NE_ANALYSER, NEAnalyser)
 	UNREGISTER(ATOM_CLASS_ANALYSER, ClassAnalyser)
 	UNREGISTER(ATOM_LE_ANALYSER, LEAnalyser)
+	UNREGISTER(ATOM_MACHO_ANALYSER, MachoAnalyser)
+	UNREGISTER(ATOM_FLT_ANALYSER, FLTAnalyser)
+	UNREGISTER(ATOM_XBE_ANALYSER, XBEAnalyser)
+	UNREGISTER(ATOM_PEF_ANALYSER, PEFAnalyser)
 
 	UNREGISTER(ATOM_ADDRESS_INVALID, InvalidAddress)
 	UNREGISTER(ATOM_ADDRESS_FLAT_32, AddressFlat32)
@@ -119,4 +139,3 @@ void done_analyser()
 	UNREGISTER(ATOM_ADDRESS_X86_1616, AddressX86_1616)
 	UNREGISTER(ATOM_ADDRESS_X86_1632, AddressX86_1632)
 }
-
