@@ -2,7 +2,7 @@
  *	HT Editor
  *	analyinfo.h
  *
- *	Copyright (C) 1999, 2000, 2001 Sebastian Biallas (sb@web-productions.de)
+ *	Copyright (C) 1999-2002 Sebastian Biallas (sb@web-productions.de)
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -22,10 +22,10 @@
 #define ANALYINFO_H
 
 #define htanalyser_name "ht-analyser"
-#define htanalyser_copyright "(c) 1999, 2000, 2001 "htanalyser_author" ("htanalyser_mail")"
+#define htanalyser_copyright "(c) 1999-2002 "htanalyser_author" ("htanalyser_mail")"
 #define htanalyser_loadtitle htanalyser_name" "htanalyser_copyright
 
 #define htanalyser_author "Sebastian Biallas"
-#define htanalyser_mail "sb@web-productions.de"
+#define htanalyser_mail "sb@biallas.net"
 
 #endif
