@@ -26,6 +26,7 @@
 #include "analy_alpha.h"
 #include "analy_names.h"
 #include "analy_register.h"
+#include "analy_ppc.h"
 #include "analy_x86.h"
 #include "coff_analy.h"
 #include "coff_s.h"
@@ -120,9 +121,9 @@ void CoffAnalyser::beginAnalysis()
 		addComment(secaddr, 0, "");
 		addComment(secaddr, 0, ";******************************************************************");
 		addComment(secaddr, 0, blub);
-		sprintf(blub, ";  virtual address  %08x  virtual size   %08x", s->data_address, s->data_vsize);
+		sprintf(blub, ";  virtual address  %08x  size   %08x", s->data_address, s->data_size);
 		addComment(secaddr, 0, blub);
-		sprintf(blub, ";  file offset      %08x  file size      %08x", s->data_offset+coff_shared->hdr_ofs, s->data_size);
+		sprintf(blub, ";  file offset      %08x", s->data_offset+coff_shared->hdr_ofs);
 		addComment(secaddr, 0, blub);
 		addComment(secaddr, 0, ";******************************************************************");
 
@@ -381,10 +382,14 @@ void CoffAnalyser::initUnasm()
 			analy_disasm = new AnalyAlphaDisassembler();
 			((AnalyAlphaDisassembler *)analy_disasm)->init(this);
 			break;
-		case COFF_MACHINE_POWERPC:	// IBM PowerPC Little-Endian
+		case COFF_MACHINE_POWERPC_LE:	// IBM PowerPC Little-Endian
 			DPRINTF("no apropriate disassembler for POWER PC\n");
 			warnbox("No disassembler for POWER PC!");
 			break;
+		case COFF_MACHINE_POWERPC_BE:
+			analy_disasm = new AnalyPPCDisassembler();
+			((AnalyPPCDisassembler*)analy_disasm)->init(this);
+			break;          
 		case COFF_MACHINE_UNKNOWN:
 		default:
 			DPRINTF("no apropriate disassembler for machine %04x\n", coff_shared->coffheader.machine);
