@@ -22,6 +22,7 @@
 #include "analy_alpha.h"
 #include "analy_names.h"
 #include "analy_ia64.h"
+#include "analy_ppc.h"
 #include "analy_register.h"
 #include "analy_x86.h"
 #include "global.h"
@@ -76,36 +77,41 @@ void ElfAnalyser::beginAnalysis()
 		}
 	}
 
+	if (!validAddress(entry, scvalid)) {
+		delete entry;
+		entry = NULL;
+	}
+
 	setLocationTreeOptimizeThreshold(100);
 	setSymbolTreeOptimizeThreshold(100);
 
-	/*
-	 *	entrypoint
-	 */
-	pushAddress(entry, entry);
-	
 	/*
 	 *	give all sections a descriptive comment:
 	 */
-
 	ELF_SECTION_HEADER32 *s32=elf_shared->sheaders.sheaders32;
 	ELF_SECTION_HEADER64 *s64=elf_shared->sheaders.sheaders64;
 	char blub[100];
-	for (UINT i=0; i < elf_shared->sheaders.count; i++) {
+	for (uint i=0; i < elf_shared->sheaders.count; i++) {
 		Address *secaddr;
 		if (c32) {
+//			fprintf(stderr, "desc sec %d, %08x\n", i, s32->sh_addr);
 			secaddr = createAddress32(s32->sh_addr);
 		} else {
 			secaddr = createAddress64(s64->sh_addr);
 		}
 		if (validAddress(secaddr, scvalid)) {
-			ht_snprintf(blub, sizeof blub, ";  section %d <%s>", i+1, getSegmentNameByAddress(secaddr));
+//			fprintf(stderr, "valid!\n");
+			ht_snprintf(blub, sizeof blub, ";  section %d <%s>", i, getSegmentNameByAddress(secaddr));
 			addComment(secaddr, 0, "");
 			addComment(secaddr, 0, ";******************************************************************");
 			addComment(secaddr, 0, blub);
 			ht_snprintf(blub, sizeof blub, ";  virtual address  %08x  virtual size   %08x", s32->sh_addr, s32->sh_size);
 			addComment(secaddr, 0, blub);
-			ht_snprintf(blub, sizeof blub, ";  file offset      %08x  file size      %08x", s32->sh_offset, s32->sh_size);
+			if (validAddress(secaddr, scinitialized)) {
+				ht_snprintf(blub, sizeof blub, ";  file offset      %08x  file size      %08x", s32->sh_offset, s32->sh_size);
+			} else {
+				ht_snprintf(blub, sizeof blub, ";  section is not in file");
+			}
 			addComment(secaddr, 0, blub);
 			addComment(secaddr, 0, ";******************************************************************");
 
@@ -132,24 +138,31 @@ void ElfAnalyser::beginAnalysis()
 		s64++;
 	}
 
-/* symbols */
+	/* symbols */
 	if (c32) {
-		for (UINT i=1; i<elf_shared->sheaders.count; i++) {
+		for (uint i=1; i<elf_shared->sheaders.count; i++) {
 			if ((elf_shared->sheaders.sheaders32[i].sh_type==ELF_SHT_SYMTAB) || (elf_shared->sheaders.sheaders32[i].sh_type==ELF_SHT_DYNSYM)) {
 				initInsertSymbols(i);
 			}
 		}
+		initInsertFakeSymbols();
 	} else {
-		for (UINT i=1; i<elf_shared->sheaders.count; i++) {
+		for (uint i=1; i<elf_shared->sheaders.count; i++) {
 			if ((elf_shared->sheaders.sheaders64[i].sh_type==ELF_SHT_SYMTAB) || (elf_shared->sheaders.sheaders64[i].sh_type==ELF_SHT_DYNSYM)) {
 				initInsertSymbols(i);
 			}
 		}
 	}
-	assignSymbol(entry, "entrypoint", label_func);
-	addComment(entry, 0, "");
-	addComment(entry, 0, ";****************************");
-	switch (c32 ? elf_shared->header32.e_type : elf_shared->header64.e_type) {
+
+	/*
+	 *	entrypoint
+	 */
+	if (entry) {
+		pushAddress(entry, entry);
+		assignSymbol(entry, "entrypoint", label_func);
+		addComment(entry, 0, "");
+		addComment(entry, 0, ";****************************");
+		switch (c32 ? elf_shared->header32.e_type : elf_shared->header64.e_type) {
 		case ELF_ET_DYN:
 			addComment(entry, 0, ";  dynamic executable entry point");
 			break;
@@ -158,30 +171,56 @@ void ElfAnalyser::beginAnalysis()
 			break;
 		default:
 			addComment(entry, 0, ";  entry point");               
+		}
+		addComment(entry, 0, ";****************************");
+		delete entry;
 	}
-	addComment(entry, 0, ";****************************");
 
 	setLocationTreeOptimizeThreshold(1000);
 	setSymbolTreeOptimizeThreshold(1000);
-	delete entry;
-	
+
 	Analyser::beginAnalysis();
 }
 
 /*
  *
  */
+void ElfAnalyser::initInsertFakeSymbols()
+{
+	if (!elf_shared->undefined2fakeaddr) return;
+	sectionAndIdx *key = NULL;
+	ht_data_uint32 *value;
+	while ((key = (sectionAndIdx*)elf_shared->undefined2fakeaddr->enum_next(
+	(Object**)&value, key))) {
+		Address *address = createAddress32(value->value);
+		FILEOFS h = elf_shared->sheaders.sheaders32[key->secidx].sh_offset;
+		ELF_SYMBOL32 sym;
+		file->seek(h+key->symidx*sizeof (ELF_SYMBOL32));
+		file->read(&sym, sizeof sym);
+		create_host_struct(&sym, ELF_SYMBOL32_struct, elf_shared->byte_order);
+
+		FILEOFS sto = elf_shared->sheaders.sheaders32[
+			elf_shared->sheaders.sheaders32[key->secidx].sh_link].sh_offset;
+		file->seek(sto+sym.st_name);
+		char *name = fgetstrz(file);
+		char buf[1024];
+		ht_snprintf(buf, sizeof buf, "undef_%s", name);
+		free(name);
+		make_valid_name(buf, buf);
+		assignSymbol(address, buf, label_func);
+	}
+}
+
 void ElfAnalyser::initInsertSymbols(int shidx)
 {
 	char elf_buffer[1024];
 	if (elf_shared->ident.e_ident[ELF_EI_CLASS] == ELFCLASS32) {
-
-		FILEOFS h=elf_shared->sheaders.sheaders32[shidx].sh_offset;
-		FILEOFS sto=elf_shared->sheaders.sheaders32[elf_shared->sheaders.sheaders32[shidx].sh_link].sh_offset;
-		UINT symnum=elf_shared->sheaders.sheaders32[shidx].sh_size / sizeof (ELF_SYMBOL32);
+		FILEOFS h = elf_shared->sheaders.sheaders32[shidx].sh_offset;
+		FILEOFS sto = elf_shared->sheaders.sheaders32[elf_shared->sheaders.sheaders32[shidx].sh_link].sh_offset;
+		uint symnum = elf_shared->sheaders.sheaders32[shidx].sh_size / sizeof (ELF_SYMBOL32);
 
 		int *entropy = random_permutation(symnum);
-		for (UINT i=0; i<symnum; i++) {
+		for (uint i=0; i<symnum; i++) {
 			ELF_SYMBOL32 sym;
 			if (entropy[i] == 0) continue;
 			file->seek(h+entropy[i]*sizeof (ELF_SYMBOL32));
@@ -224,9 +263,14 @@ void ElfAnalyser::initInsertSymbols(int shidx)
 			switch (ELF32_ST_TYPE(sym.st_info)) {
 				case ELF_STT_NOTYPE:
 				case ELF_STT_FUNC: {
-				char *label = name;
+					char *label = name;
 					if (!getSymbolByName(label)) {
-						Address *address = createAddress32(sym.st_value);
+						elf32_addr sym_addr = sym.st_value;
+						if (elf_shared->shrelocs && (sym.st_shndx>0) && (sym.st_shndx<elf_shared->sheaders.count)
+						&& elf_shared->shrelocs[sym.st_shndx].relocAddr) {
+							sym_addr += elf_shared->shrelocs[sym.st_shndx].relocAddr;
+						}
+						Address *address = createAddress32(sym_addr);
 						if (validAddress(address, scvalid)) {
 							char *demangled = cplus_demangle(label, DMGL_PARAMS | DMGL_ANSI);
 
@@ -282,10 +326,10 @@ void ElfAnalyser::initInsertSymbols(int shidx)
 		// FIXME: 64 bit
 		FILEOFS h=elf_shared->sheaders.sheaders64[shidx].sh_offset.lo;
 		FILEOFS sto=elf_shared->sheaders.sheaders64[elf_shared->sheaders.sheaders64[shidx].sh_link].sh_offset.lo;
-		UINT symnum=elf_shared->sheaders.sheaders64[shidx].sh_size.lo / sizeof (ELF_SYMBOL64);
+		uint symnum=elf_shared->sheaders.sheaders64[shidx].sh_size.lo / sizeof (ELF_SYMBOL64);
 
 		int *entropy = random_permutation(symnum);
-		for (UINT i=0; i<symnum; i++) {
+		for (uint i=0; i<symnum; i++) {
 			ELF_SYMBOL64 sym;
 			if (entropy[i] == 0) continue;
 			file->seek(h+entropy[i]*sizeof (ELF_SYMBOL64));
@@ -411,7 +455,7 @@ OBJECT_ID ElfAnalyser::object_id() const
 /*
  *
  */
-UINT ElfAnalyser::bufPtr(Address *Addr, byte *buf, int size)
+uint ElfAnalyser::bufPtr(Address *Addr, byte *buf, int size)
 {
 	FILEOFS ofs = addressToFileofs(Addr);
 /*     if (ofs == INVALID_FILE_OFS) {
@@ -419,7 +463,7 @@ UINT ElfAnalyser::bufPtr(Address *Addr, byte *buf, int size)
 	}*/
 	assert(ofs != INVALID_FILE_OFS);
 	file->seek(ofs);
-	return file->read(buf, size);;
+	return file->read(buf, size);
 }
 
 bool ElfAnalyser::convertAddressToELFAddress(Address *addr, ELFAddress *r)
@@ -507,17 +551,21 @@ FILEOFS ElfAnalyser::addressToFileofs(Address *Addr)
 /*
  *
  */
-char elf_sectionname[33];
 
 char *ElfAnalyser::getSegmentNameByAddress(Address *Addr)
 {
+	static char elf_sectionname[33];
 	elf_section_headers *sections=&elf_shared->sheaders;
 	int i;
 	ELFAddress ea;
 	if (!convertAddressToELFAddress(Addr, &ea)) return NULL;
 	if (!elf_addr_to_section(sections, elf_shared->ident.e_ident[ELF_EI_CLASS], ea, &i)) return NULL;
-	strncpy(elf_sectionname, elf_shared->shnames[i], 32);
-	elf_sectionname[32]=0;
+	if (i == elf_shared->fake_undefined_shidx) {
+		strcpy(elf_sectionname, "$$HT_FAKE$$");
+	} else {
+		strncpy(elf_sectionname, elf_shared->shnames[i], 32);
+		elf_sectionname[32] = 0;
+	}
 	return elf_sectionname;
 }
 
@@ -571,6 +619,24 @@ void ElfAnalyser::initUnasm()
 				((AnalyIA64Disassembler*)analy_disasm)->init(this);
 			}
 			break;
+		case ELF_EM_PPC: // PowerPC
+			if (elf_shared->ident.e_ident[ELF_EI_CLASS] != ELFCLASS32) {
+				errorbox("Intel PowerPC cant be used in a 64-Bit ELF.");
+			} else {
+				DPRINTF("initing analy_ppc_disassembler\n");
+				analy_disasm = new AnalyPPCDisassembler();
+				((AnalyPPCDisassembler*)analy_disasm)->init(this);
+			}
+			break;
+		case ELF_EM_PPC64: // PowerPC64
+			if (elf_shared->ident.e_ident[ELF_EI_CLASS] != ELFCLASS64) {
+				errorbox("Intel PowerPC64 cant be used in a 32-Bit ELF.");
+			} else {
+				DPRINTF("initing analy_ppc_disassembler\n");
+				analy_disasm = new AnalyPPCDisassembler();
+				((AnalyPPCDisassembler*)analy_disasm)->init(this);
+			}
+			break;
 		default:
 			DPRINTF("no apropriate disassembler for machine %04x\n", machine);
 			warnbox("No disassembler for unknown machine type %04x!", machine);
@@ -688,5 +754,3 @@ bool ElfAnalyser::validAddress(Address *Addr, tsectype action)
 	}
 	return false;
 }
-
-
