@@ -2,7 +2,7 @@
  *	The HT Editor
  *	asm.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -126,7 +126,7 @@ public:
 			~Disassembler();
 /* new */
 	virtual	dis_insn *createInvalidInsn();
-	virtual	dis_insn *decode(byte *code, byte maxlen, CPU_ADDR cur_address)=0;
+	virtual	dis_insn *decode(byte *code, int maxlen, CPU_ADDR cur_address)=0;
 	virtual	dis_insn *duplicateInsn(dis_insn *disasm_insn)=0;
 	virtual	void	getOpcodeMetrics(int &min_length, int &max_length, int &min_look_ahead, int &avg_look_ahead, int &addr_align)=0;
 	virtual	byte getSize(dis_insn *disasm_insn)=0;
@@ -173,6 +173,7 @@ public:
 #define ATOM_DISASM_IA64 MAGICD("DIS\x04")
 #define ATOM_DISASM_IL MAGICD("DIS\x05")
 #define ATOM_DISASM_X86_VXD MAGICD("DIS\x06")
+#define ATOM_DISASM_PPC MAGICD("DIS\x07")
 
 #define ASM_SYNTAX_DEFAULT "\\@d"
 #define ASM_SYNTAX_COMMENT "\\@#"
