@@ -2,7 +2,7 @@
  *	HT Editor
  *	javadis.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -44,7 +44,7 @@ javadis::~javadis()
 {
 }
 
-dis_insn *javadis::decode(byte *code, byte Maxlen, CPU_ADDR Addr)
+dis_insn *javadis::decode(byte *code, int Maxlen, CPU_ADDR Addr)
 {
 	ocodep = code;
 /* initialize */
