@@ -2,7 +2,7 @@
  *	HT Editor
  *	x86asm.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -651,7 +651,15 @@ int x86asm::encode_sib_v(x86_insn_op *op, int mindispsize, int *_ss, int *_index
 				return 0;
 		}
 	}
-	if ((index==X86_REG_SP) && (scale>1)) return 0;
+	if (index==X86_REG_SP) {
+		if (scale>1) return 0;
+		if (scale == 1) {
+			if (base==X86_REG_SP) return 0;
+			int temp = index;
+			index = base;
+			base = temp;
+		}
+	}
 	if (index!=X86_REG_NO) {
 		switch (scale) {
 			case 1:
@@ -973,7 +981,7 @@ void x86asm::match_opcodes(x86opc_insn *opcodes, x86asm_insn *insn, int prefix)
 		if (!opcodes[i].name) {
 			x86opc_insn_op_special special=*((x86opc_insn_op_special*)(&opcodes[i].op[0]));
 			if (special.type==SPECIAL_TYPE_GROUP) {
-				x86opc_insn *group=x86_group_insns[special.data];
+				x86opc_insn *group=x86_group_insns[(unsigned char)special.data];
 				for (int g=0; g<8; g++) {
 					match_opcode(&group[g], insn, prefix, i, g);
 				}
