@@ -2,7 +2,7 @@
  *	HT Editor
  *	x86dis.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -66,7 +66,7 @@ x86dis::~x86dis()
 {
 }
 
-dis_insn *x86dis::decode(byte *code, byte Maxlen, CPU_ADDR Addr)
+dis_insn *x86dis::decode(byte *code, int Maxlen, CPU_ADDR Addr)
 {
 	ocodep=code;
 /* initialize */
@@ -838,7 +838,7 @@ void x86dis::str_op(char *opstr, int *opstrlen, x86dis_insn *insn, x86_insn_op *
 				}
 			}
 			if (insn->eaddrsize==X86_ADDRSIZE16) reg=1; else reg=2;
-			if (insn->segprefix!=X86_PREFIX_NO) d+=sprintf(d, "%s%s:%s", x86_segs[insn->segprefix], cs_symbol, cs_default);
+			if (insn->segprefix!=X86_PREFIX_NO) d+=sprintf(d, "%s%s:%s", x86_segs[(unsigned char)insn->segprefix], cs_symbol, cs_default);
 			strcpy(d, cs_symbol); d += strlen(cs_symbol);
 			*(d++)='[';
 			strcpy(d, cs_default); d += strlen(cs_default);
