@@ -2,7 +2,7 @@
  *	HT Editor
  *	formats.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -30,10 +30,13 @@
 #include "htelf.h"
 #include "htcoff.h"
 #include "htle.h"
+#include "htmacho.h"
 #include "htmz.h"
 #include "htne.h"
 #include "htpe.h"
-#include "htstruct.h"
+#include "htpef.h"
+#include "htflt.h"
+#include "htxbe.h"
 
 format_viewer_if *format_viewer_ifs[] =
 {
@@ -48,6 +51,9 @@ format_viewer_if *format_viewer_ifs[] =
 	&htpe_if,
 	&htne_if,
 	&htle_if,
-//	&htstructure_if,
-	0
+	&htmacho_if,
+	&htflt_if,
+	&htxbe_if,
+	&htpef_if,
+	NULL
 };
