@@ -2,7 +2,7 @@
  *	HT Editor
  *	htapp.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -64,9 +64,9 @@ extern "C" {
 #include "regex.h"
 }
 
-#define ATOM_HT_APP					MAGICD("APP\x00")
-#define ATOM_HT_PROJECT				MAGICD("APP\x01")
-#define ATOM_HT_PROJECT_ITEM			MAGICD("APP\x02")
+#define ATOM_HT_APP			MAGICD("APP\x00")
+#define ATOM_HT_PROJECT			MAGICD("APP\x01")
+#define ATOM_HT_PROJECT_ITEM		MAGICD("APP\x02")
 #define ATOM_COMPARE_KEYS_PROJECT_ITEM	MAGICD("APP\x10")
 
 #define HT_PROJECT_CONFIG_SUFFIX     	".htprj"
@@ -117,7 +117,7 @@ bool file_new_dialog(UINT *mode)
 	b.x=0;
 	b.y=0;
 		
-/* mode (input) */
+	/* mode (input) */
 	c=b;
 	c.x=0;
 	c.y=1;
@@ -133,7 +133,7 @@ bool file_new_dialog(UINT *mode)
 
 	d->insert(mode_input);
 	
-/* mode (text) */
+	/* mode (text) */
 	c=b;
 	c.x=0;
 	c.y=0;
@@ -194,7 +194,7 @@ protected:
 	ht_strinputfield *name_input;
 	FileBrowserVfsListbox *listbox;
 public:
-	virtual	void	init(bounds *b, bounds *clientarea, const char *title, const char *starturl);
+	virtual	void init(bounds *b, bounds *clientarea, const char *title, const char *starturl);
 /* new */
 	virtual	bool extract_url(char *buf);
 	virtual	void listbox_changed();
@@ -219,7 +219,8 @@ void FileBrowser::init(bounds *n, bounds *clientarea, const char *title, const c
 {
 	ht_dialog::init(n, title, FS_KILLER | FS_TITLE | FS_MOVE | FS_RESIZE);
 	bounds b = *clientarea, c;
-/* name (input) */
+
+	/* name (input) */
 	c = b;
 	c.x = 1;
 	c.y = 1;
@@ -233,7 +234,7 @@ void FileBrowser::init(bounds *n, bounds *clientarea, const char *title, const c
 
 	insert(name_input);
 	
-/* name (text) */
+	/* name (text) */
 	c = b;
 	c.x = 1;
 	c.y = 0;
@@ -245,7 +246,7 @@ void FileBrowser::init(bounds *n, bounds *clientarea, const char *title, const c
 
 	insert(name_text);
 
-/* vfslistbox */
+	/* vfslistbox */
 	c = b;
 	c.x = 1;
 	c.y = 4;
@@ -257,7 +258,7 @@ void FileBrowser::init(bounds *n, bounds *clientarea, const char *title, const c
 
 	insert(listbox);
 
-/* vfslistbox (text) */
+	/* vfslistbox (text) */
 	c = b;
 	c.x = 1;
 	c.y = 3;
@@ -274,7 +275,7 @@ bool FileBrowser::extract_url(char *buf)
 {
 	ht_strinputfield_data i;
 	name_input->databuf_get(&i, sizeof i);
-/*     ht_text_listbox_item *t = (ht_text_listbox_item*)listbox->getbyid(d.listbox.cursor_id);
+/*	ht_text_listbox_item *t = (ht_text_listbox_item*)listbox->getbyid(d.listbox.cursor_id);
 	vfs_extra *x = (vfs_extra*)t->extra_data;*/
 	Vfs *vfs = listbox->getCurVfs();
 	if (vfs) {
@@ -329,16 +330,16 @@ bool file_chooser(const char *title, char *buf, int bufsize)
 
 	FileBrowser *d = new FileBrowser();
 	d->init(&b, &c, title, cwd);
-	
+
 	ht_list *hist = (ht_list*)find_atom(HISTATOM_FILE);
-	
+
 	/* go! */
 	if (d->run(false)) {
 		char b[VFS_URL_MAX];
 		d->extract_url(b);
 
 		// FIXME: urls not fully supported...
-		if (strcmp(b, "local:")) {
+		if (strncmp(b, "local:", 6) == 0) {
 			ht_snprintf(buf, bufsize, "%s", b+6);
 
 			if (hist) insert_history_entry(hist, buf, 0);
@@ -384,7 +385,7 @@ bool file_open_dialog(char **name, UINT *mode)
 	
 	ht_list *hist = (ht_list*)find_atom(HISTATOM_FILE);
 	
-/* mode (input) */
+	/* mode (input) */
 	c=b;
 	c.x=6;
 	c.y=b.h-4;
@@ -400,7 +401,7 @@ bool file_open_dialog(char **name, UINT *mode)
 
 	d->insert(mode_input);
 	
-/* mode (text) */
+	/* mode (text) */
 	c=b;
 	c.x=1;
 	c.y=b.h-4;
@@ -411,7 +412,8 @@ bool file_open_dialog(char **name, UINT *mode)
 	mode_text->init(&c, "~mode", mode_input);
 
 	d->insert(mode_text);
-/* go! */
+
+	/* go! */
 	if (d->run(false)) {
 		struct {
 			FileBrowserData browser;
@@ -424,7 +426,7 @@ bool file_open_dialog(char **name, UINT *mode)
 		d->extract_url(buf);
 
 		// FIXME: urls not fully supported...
-		if (strcmp(buf, "local:")) {
+		if (strncmp(buf, "local:", 6) == 0) {
 			*name = strdup(buf+6);
 
 			if (hist) insert_history_entry(hist, *name, 0);
@@ -616,7 +618,7 @@ int app_out_of_memory_proc(int size)
  *	CLASS ht_project
  */
 
-static int compare_keys_project_item(ht_data *key_a, ht_data *key_b)
+static int compare_keys_project_item(Object *key_a, Object *key_b)
 {
 	ht_project_item *a=(ht_project_item *)key_a;
 	ht_project_item *b=(ht_project_item *)key_b;
@@ -653,7 +655,7 @@ OBJECT_ID ht_project::object_id() const
 	return ATOM_HT_PROJECT;
 }
 
-void	ht_project::store(ht_object_stream *s)
+void ht_project::store(ht_object_stream *s)
 {
 	return ht_sorted_list::store(s);
 }
@@ -1359,7 +1361,7 @@ ht_app_window_entry::~ht_app_window_entry()
 {
 }
 
-static int compare_keys_app_window_entry(ht_data *key_a, ht_data *key_b)
+static int compare_keys_app_window_entry(Object *key_a, Object *key_b)
 {
 	UINT a=((ht_app_window_entry*)key_a)->number;
 	UINT b=((ht_app_window_entry*)key_b)->number;
@@ -1429,9 +1431,10 @@ void ht_app::init(bounds *pq)
 
 	syntax_lexers->insert(html_lexer);
 	
-/* init timer */
+	/* init timer */
 	h0=new_timer();
-/* create menu */
+
+	/* create menu */
 	getbounds(&b);
 	b.x=0;
 	b.y=0;
@@ -1446,7 +1449,7 @@ void ht_app::init(bounds *pq)
 	file->insert_entry("~Save", NULL, cmd_file_save, 0, 1);
 	file->insert_entry("Save ~As...", NULL, cmd_file_saveas, 0, 1);
 	file->insert_separator();
-	file->insert_entry("Open ~project...", NULL, cmd_project_open, 0, 1);
+	file->insert_entry("Open/Create ~project...", NULL, cmd_project_open, 0, 1);
 	file->insert_entry("Close p~roject", NULL, cmd_project_close, 0, 1);
 	file->insert_separator();
 	file->insert_entry("~Execute", "Alt+Z", cmd_file_exec_cmd, K_Alt_Z, 1);
@@ -1498,14 +1501,14 @@ void ht_app::init(bounds *pq)
 	menu=m;
 	insert(menu);
 	
-/* create status */
+	/* create status */
 	/* the status should have the same bounds as the menu */
 	ht_status *status = new ht_status();
 	status->init(&b);
 	status->setpalette(menu->getpalette());
 	insert(status);
 	
-/* create desktop */
+	/* create desktop */
 	getbounds(&b);
 	b.x=0;
 	b.y=1;
@@ -1513,7 +1516,8 @@ void ht_app::init(bounds *pq)
 	desktop=new ht_desktop();
 	desktop->init(&b);
 	insert(desktop);
-/* create keyline */
+	
+	/* create keyline */
 	getbounds(&b);
 	b.x=0;
 	b.y=b.h-1;
@@ -1521,7 +1525,8 @@ void ht_app::init(bounds *pq)
 	keyline=new ht_keyline();
 	keyline->init(&b);
 	insert(keyline);
-/* create battlefield */
+
+	/* create battlefield */
 	getbounds(&b);
 	b.x=0;
 	b.y=1;
@@ -1564,7 +1569,7 @@ bool ht_app::accept_close_all_windows()
 	return true;
 }
 
-bool ht_app::create_window_log()
+ht_window *ht_app::create_window_log()
 {
 	ht_window *w=get_window_by_type(AWT_LOG);
 	if (w) {
@@ -1599,10 +1604,10 @@ bool ht_app::create_window_log()
 		
 		insert_window(logwindow, AWT_LOG, 0, false, NULL);
 	}
-	return true;
+	return w;
 }
 
-bool ht_app::create_window_term(const char *cmd)
+ht_window *ht_app::create_window_term(const char *cmd)
 {
 	ht_window *w = get_window_by_type(AWT_TERM);
 	if (w) {
@@ -1654,18 +1659,18 @@ bool ht_app::create_window_term(const char *cmd)
 			insert_window(termwindow, AWT_LOG, 0, false, NULL);
 		} else {
 			errorbox("couldn't create child-process (%d)", e);
-			return false;
+			return NULL;
 		}
 	}
-	return true;
+	return w;
 }
 
-bool ht_app::create_window_clipboard()
+ht_window *ht_app::create_window_clipboard()
 {
 	ht_window *w=get_window_by_type(AWT_CLIPBOARD);
 	if (w) {
 		focus(w);
-		return true;
+		return w;
 	} else {
 		bounds b;
 		get_stdbounds_file(&b);
@@ -1674,7 +1679,7 @@ bool ht_app::create_window_clipboard()
 		ht_window *window=new ht_window();
 		window->init(&b, "clipboard", FS_KILLER | FS_TITLE | FS_NUMBER | FS_MOVE | FS_RESIZE, 0);
 		
-/*	     bounds k=b;
+/*		bounds k=b;
 		k.x=b.w-2;
 		k.y=0;
 		k.w=1;
@@ -1709,20 +1714,20 @@ bool ht_app::create_window_clipboard()
 //		insert_window(window, AWT_CLIPBOARD, 0, false, clipboard);
 		insert_window(window, AWT_CLIPBOARD, 0, false, NULL);
 	}
-	return false;
+	return NULL;
 }
-			
-bool ht_app::create_window_file(char *filename, UINT mode, bool allow_duplicates)
+
+ht_window *ht_app::create_window_file(char *filename, UINT mode, bool allow_duplicates)
 {
 	if (mode==FOM_AUTO) mode=autodetect_file_open_mode(filename);
 	switch (mode) {
 		case FOM_BIN: return create_window_file_bin(filename, allow_duplicates);
 		case FOM_TEXT: return create_window_file_text(filename, allow_duplicates);
 	}
-	return false;
+	return NULL;
 }
 
-bool ht_app::create_window_file_bin(char *filename, bool allow_duplicates)
+ht_window *ht_app::create_window_file_bin(char *filename, bool allow_duplicates)
 {
 	bounds b;
 	get_stdbounds_file(&b);
@@ -1730,13 +1735,13 @@ bool ht_app::create_window_file_bin(char *filename, bool allow_duplicates)
 	char fullfilename[FILENAME_MAX];
 	if ((e=sys_canonicalize(fullfilename, filename))) {
 		LOG_EX(LOG_ERROR, "error loading file %s: %s", fullfilename, strerror(e & ~STERR_SYSTEM));
-		return false;
+		return NULL;
 	}
 
 	ht_window *w;
 	if (!allow_duplicates && ((w = get_window_by_filename(fullfilename)))) {
 		focus(w);
-		return true;
+		return w;
 	}
 
 	ht_file *emfile = new ht_file();
@@ -1744,10 +1749,10 @@ bool ht_app::create_window_file_bin(char *filename, bool allow_duplicates)
 
 	if ((e = emfile->get_error())) {
 		LOG_EX(LOG_ERROR, "error loading file %s: %s", fullfilename, strerror(e & ~STERR_SYSTEM));
-		return false;
+		return NULL;
 	}
 
-	if (!doFileChecks(emfile)) return false;
+	if (!doFileChecks(emfile)) return NULL;
 
 	ht_streamfile_modifier *mfile = new ht_streamfile_modifier();
 	mfile->init(emfile, true, 8*1024);
@@ -1757,7 +1762,7 @@ bool ht_app::create_window_file_bin(char *filename, bool allow_duplicates)
 			 
 	if ((e=file->get_error())) {
 		LOG_EX(LOG_ERROR, "error loading file %s: %s", fullfilename, strerror(e & ~STERR_SYSTEM));
-		return false;
+		return NULL;
 	}
 	LOG("loading binary file %s...", fullfilename);
 	file->set_error_func(app_stream_error_func);
@@ -1765,7 +1770,7 @@ bool ht_app::create_window_file_bin(char *filename, bool allow_duplicates)
 	return create_window_file_bin(&b, file, fullfilename, true);
 }
 
-bool ht_app::create_window_file_bin(bounds *b, ht_layer_streamfile *file, char *title, bool isfile)
+ht_window *ht_app::create_window_file_bin(bounds *b, ht_layer_streamfile *file, char *title, bool isfile)
 {
 	ht_file_window *window = new ht_file_window();
 	window->init(b, title, FS_KILLER | FS_TITLE | FS_NUMBER | FS_MOVE | FS_RESIZE, 0, file);
@@ -1801,7 +1806,8 @@ bool ht_app::create_window_file_bin(bounds *b, ht_layer_streamfile *file, char *
 	format_group->init(&k, VO_SELECTABLE | VO_RESIZE, VIEWERGROUP_NAME, file, true, true, format_viewer_ifs, NULL);
 
 	window->insert(format_group);
-/**/
+
+	/**/
 	if (isfile) {
 		char cfgfilename[FILENAME_MAX];
 		strcpy(cfgfilename, title);
@@ -1828,7 +1834,8 @@ bool ht_app::create_window_file_bin(bounds *b, ht_layer_streamfile *file, char *
 			LOG("%s: ok", cfgfilename);
 		}
 	}
-/**/
+
+	/**/
 	if (isfile) LOG("%s: done.", title);
 
 	htmsg m;
@@ -1837,10 +1844,10 @@ bool ht_app::create_window_file_bin(bounds *b, ht_layer_streamfile *file, char *
 	window->sendmsg(&m);
 
 	insert_window(window, AWT_FILE, 0, isfile, file);
-	return true;
+	return window;
 }
 
-bool ht_app::create_window_file_text(char *filename, bool allow_duplicates)
+ht_window *ht_app::create_window_file_text(char *filename, bool allow_duplicates)
 {
 	bounds b, c;
 	get_stdbounds_file(&c);
@@ -1849,13 +1856,13 @@ bool ht_app::create_window_file_text(char *filename, bool allow_duplicates)
 	char fullfilename[FILENAME_MAX];
 	if ((e=sys_canonicalize(fullfilename, filename))) {
 		LOG_EX(LOG_ERROR, "error loading file %s: %s", fullfilename, strerror(e & ~STERR_SYSTEM));
-		return false;
+		return NULL;
 	}
 
 	ht_window *w;
 	if (!allow_duplicates && ((w = get_window_by_filename(fullfilename)))) {
 		focus(w);
-		return true;
+		return w;
 	}
 
 	ht_file *emfile = new ht_file();
@@ -1863,10 +1870,10 @@ bool ht_app::create_window_file_text(char *filename, bool allow_duplicates)
 
 	if ((e=emfile->get_error())) {
 		LOG_EX(LOG_ERROR, "error loading file %s: %s", fullfilename, strerror(e & ~STERR_SYSTEM));
-		return false;
+		return NULL;
 	}
 
-	if (!doFileChecks(emfile)) return false;
+	if (!doFileChecks(emfile)) return NULL;
 
 	ht_ltextfile *tfile = new ht_ltextfile();
 	tfile->init(emfile, true, NULL);
@@ -1876,7 +1883,7 @@ bool ht_app::create_window_file_text(char *filename, bool allow_duplicates)
 
 	if ((e=file->get_error())) {
 		LOG_EX(LOG_ERROR, "error loading file %s: %s", fullfilename, strerror(e & ~STERR_SYSTEM));
-		return false;
+		return NULL;
 	}
 
 	LOG("loading text file %s...", fullfilename);
@@ -1885,7 +1892,7 @@ bool ht_app::create_window_file_text(char *filename, bool allow_duplicates)
 	return create_window_file_text(&b, file, fullfilename, true);
 }
 
-bool ht_app::create_window_file_text(bounds *c, ht_layer_streamfile *f, char *title, bool isfile)
+ht_window *ht_app::create_window_file_text(bounds *c, ht_layer_streamfile *f, char *title, bool isfile)
 {
 	bounds b=*c;
 
@@ -1943,16 +1950,15 @@ bool ht_app::create_window_file_text(bounds *c, ht_layer_streamfile *f, char *ti
 	if (isfile) LOG("%s: done.", title);
 
 	insert_window(window, AWT_FILE, 0, isfile, file);
-
-	return true;
+	return window;
 }
 
-bool ht_app::create_window_help(char *file, char *node)
+ht_window *ht_app::create_window_help(char *file, char *node)
 {
-	ht_window *w=get_window_by_type(AWT_HELP);
+	ht_window *w = get_window_by_type(AWT_HELP);
 	if (w) {
 		focus(w);
-		return true;
+		return w;
 	} else {
 		bounds b, c;
 		battlefield->getbounds(&c);
@@ -2008,21 +2014,21 @@ bool ht_app::create_window_help(char *file, char *node)
 			insert_window(window, AWT_HELP, 0, false, NULL);
 			
 			window->setpalette(palkey_generic_cyan);
-
-			return true;
+			return window;
 		}
 		errorbox("help topic '(%s)%s' not found", file, node);
 		window->done();
 		delete window;
 	}
-	return false;
+	return NULL;
 }
 
-bool ht_app::create_window_project()
+ht_window *ht_app::create_window_project()
 {
 	ht_window *w=get_window_by_type(AWT_PROJECT);
 	if (w) {
 		focus(w);
+		return w;
 	} else {
 		bounds b;
 		get_stdbounds_tool(&b);
@@ -2051,8 +2057,8 @@ bool ht_app::create_window_project()
 		insert_window(project_window, AWT_PROJECT, 0, false, NULL);
 		
 		project_window->setpalette(palkey_generic_cyan);
+		return project_window;
 	}
-	return true;
 }
 
 #if 0
@@ -2093,7 +2099,7 @@ ht_view *create_ofm_single(bounds *c, char *url, ht_vfs_viewer **x)
 }
 #endif
 
-bool ht_app::create_window_ofm(char *url1, char *url2)
+ht_window *ht_app::create_window_ofm(char *url1, char *url2)
 {
 	bounds b;
 	get_stdbounds_file(&b);
@@ -2107,7 +2113,7 @@ bool ht_app::create_window_ofm(char *url1, char *url2)
 	VfsListbox2 *l = new VfsListbox2();
 	l->init(&b, virtual_fs_list, window->getframe());
 
-//     l->changeURL("local:/bp/././..");
+//	l->changeURL("local:/bp/././..");
 	l->changeURL(url1);
 
 	window->insert(l);
@@ -2145,7 +2151,7 @@ bool ht_app::create_window_ofm(char *url1, char *url2)
 	}
 #endif
 	insert_window(window, AWT_OFM, 0, false, NULL);
-	return true;
+	return window;
 }
 
 char *ht_app::defaultpalette()
@@ -2175,10 +2181,6 @@ void ht_app::draw()
 	buf->printf(57, 1, 7, "avg%d: %d", max_timing+1, avg*1024);
 #endif
 #endif
-/* display flag if analyser(s) active */
-/*	char *analysers[] = {"Analy", "aNaly", "anAly", "anaLy", "analY", "anaLy", "anAly", "aNaly"};
-	if (some_analyser_active) buf->printf(60, 0, VCP(VC_TRANSPARENT, VC_TRANSPARENT), "%s (%d)", analysers[analy_id++], num_ops_parsed);
-	if (analy_id > 7) analy_id = 0;*/
 }
 
 void ht_app::delete_window(ht_window *window)
@@ -2548,13 +2550,14 @@ void ht_app::handlemsg(htmsg *msg)
 		case cmd_file_extend: {
 			ht_streamfile *f = (ht_streamfile *)msg->data1.ptr;
 			UINT s = (UINT)msg->data2.integer;
-			if (confirmbox("really extend %s to offset %08x/%d ?", f->get_filename(), s, s) == button_ok) {
+			// don't ask. only for truncates
+//			if (confirmbox("really extend %s to offset %08x/%d ?", f->get_filename(), s, s) == button_ok) {
 				int oam = f->get_access_mode();
 				if (!(oam & FAM_WRITE)) f->set_access_mode(oam | FAM_WRITE);
 				int e = f->extend(s);
 				if (!(oam & FAM_WRITE)) f->set_access_mode(oam);
 				if (e) errorbox("couldn't extend file to offset %08x/%d: %s", s, s, strerror(e));
-			}
+//			}
 			clearmsg(msg);
 			return;
 		}
@@ -2622,7 +2625,11 @@ void ht_app::handlemsg(htmsg *msg)
 						ht_layer_streamfile *file = new ht_layer_streamfile();
 						file->init(modfile, true);
 
-						create_window_file_bin(&b, file, "Untitled", false);
+						ht_window *w = create_window_file_bin(&b, file, "Untitled", false);
+						htmsg m;
+						m.msg = cmd_file_resize;
+						m.type = mt_empty;
+						w->sendmsg(&m);
 					}
 				}
 			}
@@ -2813,7 +2820,7 @@ ht_view *ht_app::popup_view_list(char *dialog_title)
 	ht_dialog *dialog=new ht_dialog();
 	dialog->init(&b, dialog_title, FS_KILLER | FS_TITLE | FS_MOVE);
 
-/* create listbox */
+	/* create listbox */
 	c=b;
 	c.x=0;
 	c.y=0;
@@ -2821,7 +2828,8 @@ ht_view *ht_app::popup_view_list(char *dialog_title)
 	c.h-=2;
 	ht_text_listbox *listbox=new ht_text_listbox();
 	listbox->init(&c, 1, 0, LISTBOX_NORMAL);
-/* insert all browsable views */
+
+	/* insert all browsable views */
 	ht_clist *structure=new ht_clist();
 	((ht_clist*)structure)->init();
 	int index=0;
@@ -2833,10 +2841,10 @@ ht_view *ht_app::popup_view_list(char *dialog_title)
 	ht_text_listbox_sort_order so[1];
 	so[0].col = 0;
 	so[0].compare_func = my_compare_func;
-/*     so[1].col = 1;
+/*	so[1].col = 1;
 	so[1].compare_func = my_compare_func;*/
 	
-//     listbox->sort(1, so);
+//	listbox->sort(1, so);
 
 	dialog->insert(listbox);
 	dialog->setpalette(palkey_generic_special);
@@ -2905,7 +2913,7 @@ ht_window *ht_app::popup_window_list(char *dialog_title)
 	ht_dialog *dialog=new ht_dialog();
 	dialog->init(&b, dialog_title, FS_KILLER | FS_TITLE | FS_MOVE);
 
-/* create listbox */
+	/* create listbox */
 	c=b;
 	c.x=0;
 	c.y=0;
@@ -3036,7 +3044,7 @@ ht_vstate_history_entry::~ht_vstate_history_entry()
  *	CLASS ht_file_window
  */
 
-void	ht_file_window::init(bounds *b, char *desc, UINT framestyle, UINT number, ht_streamfile *f)
+void ht_file_window::init(bounds *b, char *desc, UINT framestyle, UINT number, ht_streamfile *f)
 {
 	ht_window::init(b, desc, framestyle, number);
 	file = f;
@@ -3094,7 +3102,13 @@ void ht_file_window::handlemsg(htmsg *msg)
 				modified = true;
 			}
 			if (modified) {
-				switch (msgbox(btmask_yes+btmask_no+btmask_cancel, "confirmation", 0, align_center, "file %s has been modified, save ?", file->get_filename())) {
+				char q[1024];
+				if (file->get_filename()) {
+					ht_snprintf(q, sizeof q, "file %s has been modified, save ?", file->get_filename());
+				} else {
+					ht_snprintf(q, sizeof q, "untitled file has been modified, save ?");
+				}
+				switch (msgbox(btmask_yes+btmask_no+btmask_cancel, "confirmation", 0, align_center, q)) {
 					case button_yes: {
 						app->focus(this);
 						htmsg msg;
@@ -3125,9 +3139,8 @@ void ht_file_window::handlemsg(htmsg *msg)
 		}
 		break;
 		case cmd_analyser_save: {
-			char filename[1024];	/* FIXME: possible buffer overflow */
-			strcpy(filename, file->get_filename());
-			strcat(filename, HT_FILE_CONFIG_SUFFIX);
+			char filename[1024];
+			ht_snprintf(filename, sizeof filename, "%s%s", file->get_filename(), HT_FILE_CONFIG_SUFFIX);
 			LOG("%s: saving config", filename);
 			save_fileconfig(filename, ht_fileconfig_magic, ht_fileconfig_fileversion, file_window_store_fcfg_func, this);
 			LOG("%s: done", filename);
@@ -3139,7 +3152,8 @@ void ht_file_window::handlemsg(htmsg *msg)
 	switch (msg->msg) {
 		case msg_keypressed:
 			switch (msg->data1.integer) {
-				case K_BackSpace: {
+				case K_Alt_Backspace:
+				case K_Backspace: {
 					sendmsg(cmd_vstate_restore);
 					clearmsg(msg);
 					return;
@@ -3158,22 +3172,22 @@ ht_list *build_vfs_list()
 	vfslist->init();
 
 #if 1
-/* LocalFS */
+	/* LocalFS */
 	LocalFs *localfs = new LocalFs();
 	localfs->init();
 
-/* RegistryFS */
+	/* RegistryFS */
 	RegistryFs *registryfs = new RegistryFs();
 	registryfs->init();
 
 	vfslist->insert(localfs);
 	vfslist->insert(registryfs);
 #else
-/* file_vfs */
+	/* file_vfs */
 	ht_file_vfs *file_vfs = new ht_file_vfs();
 	file_vfs->init();
 
-/* reg_vfs */
+	/* reg_vfs */
 	ht_reg_vfs *reg_vfs = new ht_reg_vfs();
 	reg_vfs->init();
 
@@ -3256,3 +3270,4 @@ void done_app()
 	
 	if (screen) delete screen;
 }
+
