@@ -2,7 +2,7 @@
  *	HT Editor
  *	htatom.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -40,7 +40,7 @@ HT_ATOM find_atom_rev(const void *data)
 	if (data) {
 		ht_data_uint *key=NULL;
 		ht_data_ptr *value;
-		while ((key=(ht_data_uint*)atoms->enum_next((ht_data**)&value, key))) {
+		while ((key=(ht_data_uint*)atoms->enum_next((Object**)&value, key))) {
 			if (value->value==data) return key->value;
 		}
 	}
