@@ -2,7 +2,7 @@
  *	HT Editor
  *	htclipboard.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -30,7 +30,7 @@
 
 ht_clipboard *clipboard;
 
-class ht_clipboard_copy_history: public ht_data {
+class ht_clipboard_copy_history: public Object {
 public:
 	virtual ~ht_clipboard_copy_history() {
 		if (source) free(source);
