@@ -2,7 +2,7 @@
  *	HT Editor
  *	htdata.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -29,12 +29,12 @@
 
 #define NEW_TREE_ENUM
 
-int (*qsort_compare_compare_keys)(ht_data *key_a, ht_data *key_b);
+int (*qsort_compare_compare_keys)(Object *key_a, Object *key_b);
 
 int qsort_compare(const void *e1, const void *e2)
 {
-	ht_data *d1=*(ht_data **)e1;
-	ht_data *d2=*(ht_data **)e2;
+	Object *d1=*(Object **)e1;
+	Object *d2=*(Object **)e2;
 	return qsort_compare_compare_keys(d1, d2);
 }
 
@@ -49,7 +49,7 @@ int qsort_compare_keys_tree_node(const void *e1, const void *e2)
  *	CLASS ht_data_uint
  */
 
-ht_data_uint::ht_data_uint(UINT v)
+ht_data_uint::ht_data_uint(uint v)
 {
 	value=v;
 }
@@ -71,28 +71,28 @@ OBJECT_ID ht_data_uint::object_id() const
 }
 
 /*
- *	CLASS ht_data_dword
+ *	ht_data_uint32
  */
 
-ht_data_dword::ht_data_dword(dword v)
+ht_data_uint32::ht_data_uint32(uint32 v)
 {
-	value=v;
+	value = v;
 }
 
-int ht_data_dword::load(ht_object_stream *s)
+int ht_data_uint32::load(ht_object_stream *s)
 {
-	value=s->getIntHex(4, NULL);
+	value = s->getIntHex(4, NULL);
 	return s->get_error();
 }
 
-void ht_data_dword::store(ht_object_stream *s)
+void ht_data_uint32::store(ht_object_stream *s)
 {
 	s->putIntHex(value, 4, NULL);
 }
 
-OBJECT_ID ht_data_dword::object_id() const
+OBJECT_ID ht_data_uint32::object_id() const
 {
-	return ATOM_HT_DATA_DWORD;
+	return ATOM_HT_DATA_UINT32;
 }
 
 /*
@@ -108,7 +108,7 @@ ht_data_ptr::ht_data_ptr(const void *v)
  *	CLASS ht_data_mem
  */
 
-ht_data_mem::ht_data_mem(const void *v, UINT _size)
+ht_data_mem::ht_data_mem(const void *v, uint _size)
 {
 	size=_size;
 	if (size) {
@@ -146,14 +146,14 @@ OBJECT_ID ht_data_mem::object_id() const
 
 void ht_tree::init(compare_keys_func_ptr _compare_keys)
 {
-	ht_data::init();
+	Object::init();
 	assert(_compare_keys);
 	compare_keys=_compare_keys;
 }
 
 void ht_tree::done()
 {
-	ht_data::done();
+	Object::done();
 }
 
 void ht_tree::destroy()
@@ -165,37 +165,37 @@ void ht_tree::balance()
 {
 }
 
-UINT ht_tree::count()
+uint ht_tree::count()
 {
 	return 0;
 }
 
-bool ht_tree::del(ht_data *key)
+bool ht_tree::del(Object *key)
 {
 	return false;
 }
 
-ht_data *ht_tree::enum_next(ht_data **value, ht_data *prevkey)
+Object *ht_tree::enum_next(Object **value, Object *prevkey)
 {
 	return NULL;
 }
 
-ht_data *ht_tree::enum_prev(ht_data **value, ht_data *nextkey)
+Object *ht_tree::enum_prev(Object **value, Object *nextkey)
 {
 	return NULL;
 }
 
-ht_data *ht_tree::get(ht_data *key)
+Object *ht_tree::get(Object *key)
 {
 	return NULL;
 }
 
-ht_data *ht_tree::get_insert(ht_data *key)
+Object *ht_tree::get_insert(Object *key)
 {
 	return NULL;
 }
 
-bool ht_tree::insert(ht_data *key, ht_data *data)
+bool ht_tree::insert(Object *key, Object *data)
 {
 	return false;
 }
@@ -252,12 +252,12 @@ void ht_stree::balance()
 	set_compare_keys(compare_keys);
 }
 
-UINT ht_stree::count()
+uint ht_stree::count()
 {
 	return node_count;
 }
 
-bool ht_stree::del(ht_data *key)
+bool ht_stree::del(Object *key)
 {
 	ht_tree_node *node, *parent;
 	int direction;
@@ -301,7 +301,7 @@ void ht_stree::empty()
 	}
 }
 
-void ht_stree::enum_next_i(ht_tree_node *node, ht_data *prevkey, ht_tree_node **retv)
+void ht_stree::enum_next_i(ht_tree_node *node, Object *prevkey, ht_tree_node **retv)
 {
 	if ((prevkey == NULL) || (compare_keys(prevkey, node->key) < 0)) {
 		*retv = node;
@@ -311,7 +311,7 @@ void ht_stree::enum_next_i(ht_tree_node *node, ht_data *prevkey, ht_tree_node **
 	}
 }
 
-void ht_stree::enum_prev_i(ht_tree_node *node, ht_data *nextkey, ht_tree_node **retv)
+void ht_stree::enum_prev_i(ht_tree_node *node, Object *nextkey, ht_tree_node **retv)
 {
 	if ((nextkey == NULL) || (compare_keys(node->key, nextkey) < 0)) {
 		*retv = node;
@@ -321,7 +321,7 @@ void ht_stree::enum_prev_i(ht_tree_node *node, ht_data *nextkey, ht_tree_node **
 	}
 }
 
-ht_data *ht_stree::enum_next(ht_data **value, ht_data *prevkey)
+Object *ht_stree::enum_next(Object **value, Object *prevkey)
 {
 #ifdef NEW_TREE_ENUM
 	ht_tree_node *n = NULL, *next = NULL;
@@ -358,7 +358,7 @@ ht_data *ht_stree::enum_next(ht_data **value, ht_data *prevkey)
 #endif
 }
 
-ht_data *ht_stree::enum_prev(ht_data **value, ht_data *nextkey)
+Object *ht_stree::enum_prev(Object **value, Object *nextkey)
 {
 #ifdef NEW_TREE_ENUM
 	ht_tree_node *n = NULL, *prev = NULL;
@@ -419,14 +419,14 @@ void ht_stree::free_skeleton(ht_tree_node *node)
 	node_count--;
 }
 
-ht_data *ht_stree::get(ht_data *key)
+Object *ht_stree::get(Object *key)
 {
 	ht_tree_node *n=get_node_i(key);
 	if (n) return n->value;
 	return NULL;
 }
 
-ht_tree_node *ht_stree::get_node_i(ht_data *key)
+ht_tree_node *ht_stree::get_node_i(Object *key)
 {
 	ht_tree_node *n=root;
 	while (n) {
@@ -438,7 +438,7 @@ ht_tree_node *ht_stree::get_node_i(ht_data *key)
 	return NULL;
 }
 
-bool ht_stree::get_node_and_parent(ht_data *key, ht_tree_node **node, ht_tree_node **parent_node, int *direction)
+bool ht_stree::get_node_and_parent(Object *key, ht_tree_node **node, ht_tree_node **parent_node, int *direction)
 {
 	ht_tree_node *p=NULL, *n=root;
 	int pc=0;
@@ -474,7 +474,7 @@ ht_tree_node *ht_stree::get_rightmost_node(ht_tree_node *node)
 	return node;
 }
 
-bool ht_stree::insert(ht_data *key, ht_data *value)
+bool ht_stree::insert(Object *key, Object *value)
 {
 //	if ((!key) || (!value)) return false;
 	if (!key) return false;
@@ -506,7 +506,7 @@ void ht_stree::insert_ltable(ht_tree_node **node, ht_tree_node **start, ht_tree_
 	}
 }
 
-void stree_load(ht_object_stream *s, ht_tree_node **n, UINT *node_count, int l, int r)
+void stree_load(ht_object_stream *s, ht_tree_node **n, uint *node_count, int l, int r)
 {
 	if (l>r) {
 		*n = NULL;
@@ -529,14 +529,14 @@ int ht_stree::load(ht_object_stream *s)
 	if (!d) return 1;
 	compare_keys=(compare_keys_func_ptr)d;
 	
-	UINT c=s->getIntDec(4, NULL);
+	uint c=s->getIntDec(4, NULL);
 #if 0
 	root=NULL;
 	node_count=0;
 	
-	for (UINT i=0; i<c; i++) {
-		ht_data *key=s->get_object(NULL);
-		ht_data *value=s->get_object(NULL);
+	for (uint i=0; i<c; i++) {
+		Object *key=s->get_object(NULL);
+		Object *value=s->get_object(NULL);
 		if (!key) return 1;
 		if (!value) return 1;
 		insert(key, value);
@@ -559,8 +559,8 @@ void ht_stree::store(ht_object_stream *s)
 	
 	s->putIntDec(count(), 4, NULL);
 	
-	ht_data *key=NULL;
-	ht_data *value;
+	Object *key=NULL;
+	Object *value;
 	while ((key=enum_next(&value, key))) {
 		if (value) {
 			s->putObject(key, NULL);
@@ -586,7 +586,7 @@ void ht_stree::populate_ltable(ht_tree_node ***ltable, ht_tree_node *node)
  *	CLASS ht_dtree (rebalancing and dead node tree)
  */
 
-void ht_dtree::init(compare_keys_func_ptr compare_keys, UINT _max_ub_delete, UINT _max_ub_insert)
+void ht_dtree::init(compare_keys_func_ptr compare_keys, uint _max_ub_delete, uint _max_ub_insert)
 {
 	ht_stree::init(compare_keys);
 	dead_node_count=0;
@@ -629,14 +629,14 @@ void ht_dtree::set_compare_keys(compare_keys_func_ptr new_compare_keys)
 	ub_insert=0;
 	if (node_count-dead_node_count) {
 		/* create ltable from tree */
-		UINT new_node_count = node_count-dead_node_count;
+		uint new_node_count = node_count-dead_node_count;
 		ht_tree_node **ltable = (ht_tree_node**)malloc(sizeof (ht_tree_node*) * new_node_count);
 		assert(ltable);
 		ht_tree_node **l = ltable;
 		populate_ltable_free_dead_nodes(&l, root);
 
 		/* save old tree, empty tree */
-		UINT old_node_count = node_count;
+		uint old_node_count = node_count;
 		node_count = 0;
 		root = NULL;
 		if (compare_keys != new_compare_keys) {
@@ -658,12 +658,12 @@ void ht_dtree::set_compare_keys(compare_keys_func_ptr new_compare_keys)
 	}
 }
 
-UINT ht_dtree::count()
+uint ht_dtree::count()
 {
 	return node_count-dead_node_count;
 }
 
-bool ht_dtree::del(ht_data *key)
+bool ht_dtree::del(Object *key)
 {
 	ht_tree_node *n=get_node_i(key);
 	if ((n) && (n->value)) {
@@ -679,7 +679,7 @@ bool ht_dtree::del(ht_data *key)
 	return false;
 }
 
-ht_data *ht_dtree::enum_next(ht_data **value, ht_data *prevkey)
+Object *ht_dtree::enum_next(Object **value, Object *prevkey)
 {
 #ifdef NEW_TREE_ENUM
 	ht_tree_node *n, *next;
@@ -712,7 +712,7 @@ ht_data *ht_dtree::enum_next(ht_data **value, ht_data *prevkey)
 	return NULL;
 #else
 	ht_tree_node *n;
-	ht_data *k = prevkey;
+	Object *k = prevkey;
 	while (1) {
 		n = NULL;
 		if (root) enum_next_i(root, k, &n);
@@ -727,7 +727,7 @@ ht_data *ht_dtree::enum_next(ht_data **value, ht_data *prevkey)
 #endif
 }
 
-ht_data *ht_dtree::enum_prev(ht_data **value, ht_data *nextkey)
+Object *ht_dtree::enum_prev(Object **value, Object *nextkey)
 {
 #ifdef NEW_TREE_ENUM
 	ht_tree_node *n, *prev;
@@ -760,7 +760,7 @@ ht_data *ht_dtree::enum_prev(ht_data **value, ht_data *nextkey)
 	return NULL;
 #else
 	ht_tree_node *n;
-	ht_data *k = nextkey;
+	Object *k = nextkey;
 	while (1) {
 		n = NULL;
 		if (root) enum_prev_i(root, k, &n);
@@ -775,7 +775,7 @@ ht_data *ht_dtree::enum_prev(ht_data **value, ht_data *nextkey)
 #endif
 }
 
-bool ht_dtree::insert(ht_data *key, ht_data *value)
+bool ht_dtree::insert(Object *key, Object *value)
 {
 	if ((!key) || (!value)) return false;
 	ht_tree_node **n=&root;
@@ -812,13 +812,13 @@ bool ht_dtree::insert(ht_data *key, ht_data *value)
 
 void ht_list::init(compare_keys_func_ptr _compare_keys)
 {
-	ht_data::init();
+	Object::init();
 	compare_keys=_compare_keys;
 }
 
 void ht_list::done()
 {
-	ht_data::done();
+	Object::done();
 }
 
 void ht_list::destroy()
@@ -826,20 +826,20 @@ void ht_list::destroy()
 	done();
 }
 
-void ht_list::append(ht_data *data)
+void ht_list::append(Object *data)
 {
 }
 
-UINT ht_list::count()
+uint ht_list::count()
 {
 	return 0;
 }
 
-void ht_list::copy_to(UINT i, UINT count, ht_list *destlist)
+void ht_list::copy_to(uint i, uint count, ht_list *destlist)
 {
-	UINT j=0;
+	uint j=0;
 	while (count--) {
-		ht_data *w=get(i+j);
+		Object *w=get(i+j);
 		if (j) {
 			destlist->insert_after(w, j-1);
 		} else {
@@ -849,17 +849,17 @@ void ht_list::copy_to(UINT i, UINT count, ht_list *destlist)
 	}
 }
 
-ht_list *ht_list::cut(UINT i, UINT count)
+ht_list *ht_list::cut(uint i, uint count)
 {
 	return NULL;
 }
 
-bool ht_list::del(UINT i)
+bool ht_list::del(uint i)
 {
 	return false;
 }
 
-bool ht_list::del_multiple(UINT i, UINT count)
+bool ht_list::del_multiple(uint i, uint count)
 {
 	bool b=true;
 	while (count--) {
@@ -872,46 +872,46 @@ void ht_list::empty()
 {
 }
 
-UINT ht_list::find(ht_data *data)
+uint ht_list::find(Object *data)
 {
 	return LIST_UNDEFINED;
 }
 
-ht_data *ht_list::get(UINT i)
+Object *ht_list::get(uint i)
 {
 	return NULL;
 }
 
-void ht_list::insert(ht_data *data)
+void ht_list::insert(Object *data)
 {
 }
 
-void ht_list::insert_after(ht_data *data, UINT i)
+void ht_list::insert_after(Object *data, uint i)
 {
 }
 
-void ht_list::insert_before(ht_data *data, UINT i)
+void ht_list::insert_before(Object *data, uint i)
 {
 }
 
-void ht_list::move(UINT source, UINT dest)
+void ht_list::move(uint source, uint dest)
 {
 }
 
-void ht_list::move_multiple(UINT source, UINT dest, UINT count)
+void ht_list::move_multiple(uint source, uint dest, uint count)
 {
 }
 
-void ht_list::prepend(ht_data *data)
+void ht_list::prepend(Object *data)
 {
 }
 
-ht_data *ht_list::remove(UINT i)
+Object *ht_list::remove(uint i)
 {
 	return NULL;
 }
 
-bool ht_list::remove_multiple(UINT i, UINT count)
+bool ht_list::remove_multiple(uint i, uint count)
 {
 	bool b=true;
 	while (count--) {
@@ -920,7 +920,7 @@ bool ht_list::remove_multiple(UINT i, UINT count)
 	return b;
 }
 
-bool ht_list::set(UINT i, ht_data *data)
+bool ht_list::set(uint i, Object *data)
 {
 	return false;
 }
@@ -944,7 +944,7 @@ void ht_clist::init(compare_keys_func_ptr compare_keys)
 {
 	ht_list::init(compare_keys);
 	c_size=HT_CLIST_ENTRY_COUNT_START;
-	items=(ht_data**)malloc(c_size * sizeof (ht_data*));
+	items=(Object**)malloc(c_size * sizeof (Object*));
 	c_entry_count=0;
 }
 
@@ -960,28 +960,28 @@ void ht_clist::destroy()
 	done();
 }
 
-void ht_clist::append(ht_data *data)
+void ht_clist::append(Object *data)
 {
 	insert_before(data, c_entry_count);
 }
 
-UINT ht_clist::count()
+uint ht_clist::count()
 {
 	return c_entry_count;
 }
 
-ht_list *ht_clist::cut(UINT start, UINT count)
+ht_list *ht_clist::cut(uint start, uint count)
 {
 	ht_clist *c=new ht_clist();
 	c->init(compare_keys);
-	for (UINT i=0; i<count; i++) {
+	for (uint i=0; i<count; i++) {
 		c->insert(items[start+i]);
 	}
 	remove_multiple(start, count);
 	return c;
 }
 
-bool ht_clist::del(UINT i)
+bool ht_clist::del(uint i)
 {
 	if (i<c_entry_count) {
 		do_free(i);
@@ -991,7 +991,7 @@ bool ht_clist::del(UINT i)
 	return false;
 }
 
-void ht_clist::do_free(UINT i)
+void ht_clist::do_free(uint i)
 {
 	if (items[i]) {
 		items[i]->done();
@@ -999,7 +999,7 @@ void ht_clist::do_free(UINT i)
 	}
 }
 
-void ht_clist::do_remove(UINT i)
+void ht_clist::do_remove(uint i)
 {
 	memmove(&items[i], &items[i+1], sizeof items[i] * (c_entry_count-i-1));
 	c_entry_count--;
@@ -1009,7 +1009,7 @@ Object *ht_clist::duplicate()
 {
 	ht_clist *d=new ht_clist();
 	d->init(compare_keys);
-	for (UINT i=0; i<c_entry_count; i++) {
+	for (uint i=0; i<c_entry_count; i++) {
 		d->insert(items[i]->duplicate());
 	}
 	return d;
@@ -1017,7 +1017,7 @@ Object *ht_clist::duplicate()
 
 void ht_clist::empty()
 {
-	for (UINT i=0; i<c_entry_count; i++) {
+	for (uint i=0; i<c_entry_count; i++) {
 		do_free(i);
 	}
 	c_entry_count=0;
@@ -1027,41 +1027,41 @@ void ht_clist::extend_list()
 {
 	c_size *= HT_CLIST_ENTRY_COUNT_EXT_NUM;
 	c_size /= HT_CLIST_ENTRY_COUNT_EXT_DEN;
-	ht_data **new_items=(ht_data**)malloc(c_size * sizeof (ht_data*));
-	memmove(new_items, items, c_entry_count * sizeof (ht_data*));
+	Object **new_items=(Object**)malloc(c_size * sizeof (Object*));
+	memmove(new_items, items, c_entry_count * sizeof (Object*));
 	free(items);
 	items=new_items;
 }
 
-UINT ht_clist::find(ht_data *data)
+uint ht_clist::find(Object *data)
 {
 	if (compare_keys) {
-		for (UINT i=0; i<c_entry_count; i++) {
+		for (uint i=0; i<c_entry_count; i++) {
 			if (compare_keys(data, items[i])==0) return i;
 		}
 	}
 	return LIST_UNDEFINED;
 }
 
-ht_data *ht_clist::get(UINT i)
+Object *ht_clist::get(uint i)
 {
 	if (i<c_entry_count) return items[i];
 	return NULL;
 }
 
-void ht_clist::insert(ht_data *data)
+void ht_clist::insert(Object *data)
 {
 	append(data);
 }
 
-void ht_clist::insert_after(ht_data *data, UINT i)
+void ht_clist::insert_after(Object *data, uint i)
 {
 	insert_before(data, i+1);
 }
 
-void ht_clist::insert_before(ht_data *data, UINT i)
+void ht_clist::insert_before(Object *data, uint i)
 {
-	UINT hi= i>c_entry_count ? i+1 : c_entry_count+1;
+	uint hi= i>c_entry_count ? i+1 : c_entry_count+1;
 	while (hi>=c_size) extend_list();
 	if (i>c_entry_count) {
 		c_entry_count=i+1;
@@ -1075,7 +1075,7 @@ void ht_clist::insert_before(ht_data *data, UINT i)
 int  ht_clist::load(ht_object_stream *s)
 {
 	c_size=HT_CLIST_ENTRY_COUNT_START;
-	items=(ht_data**)malloc(c_size * sizeof (ht_data*));
+	items=(Object**)malloc(c_size * sizeof (Object*));
 	c_entry_count=0;
 	
 	void *d=find_atom(s->getIntHex(4, NULL));
@@ -1084,27 +1084,27 @@ int  ht_clist::load(ht_object_stream *s)
 	
 	int c=s->getIntDec(4, "item_count");
 	for (int i=0; i<c; i++) {
-		ht_data *d=s->getObject("item");
+		Object *d=s->getObject("item");
 		if (s->get_error()) break;
 		prepend(d);
 	}
 	return s->get_error();
 }
 
-void ht_clist::move(UINT source, UINT dest)
+void ht_clist::move(uint source, uint dest)
 {
 	if (dest<=c_entry_count) {
-		ht_data *src=get(source);
+		Object *src=get(source);
 		memmove(items+source, items+source+1, sizeof items[0] * (c_entry_count-source-1));
 		memmove(items+dest+1, items+dest, sizeof items[0] * (c_entry_count-dest-1));
 		items[dest]=src;
 	}
 }
 
-void ht_clist::move_multiple(UINT source, UINT dest, UINT count)
+void ht_clist::move_multiple(uint source, uint dest, uint count)
 {
 	if (dest<=c_entry_count) {
-		for (UINT i=0; i<count; i++) {
+		for (uint i=0; i<count; i++) {
 			move(source, dest+count-1);
 		}
 	}
@@ -1115,22 +1115,22 @@ OBJECT_ID ht_clist::object_id() const
 	return ATOM_HT_CLIST;
 }
 
-void ht_clist::prepend(ht_data *data)
+void ht_clist::prepend(Object *data)
 {
 	insert_before(data, 0);
 }
 
-ht_data *ht_clist::remove(UINT i)
+Object *ht_clist::remove(uint i)
 {
 	if (i<c_entry_count) {
-		ht_data *d=items[i];
+		Object *d=items[i];
 		do_remove(i);
 		return d;
 	}
 	return NULL;
 }
 
-bool ht_clist::set(UINT i, ht_data *data)
+bool ht_clist::set(uint i, Object *data)
 {
 	while (i>=c_entry_count) append(NULL);
 	do_free(i);
@@ -1160,7 +1160,7 @@ void ht_clist::store(ht_object_stream *s)
 
 !!! THERE'S A BUG IN HERE !!!
 
-bool ht_clist::qsort_i(UINT _l, UINT _r)
+bool ht_clist::qsort_i(uint _l, uint _r)
 {
 	int xchg_count=0;
 	int l=(int)_l;
@@ -1168,13 +1168,13 @@ bool ht_clist::qsort_i(UINT _l, UINT _r)
 	int m=(l+r) / 2;
 	int origl=l;
 	int origr=r;
-	ht_data *c;
+	Object *c;
 	c=items[m];
 	do {
 		while ((l<m) && compare_keys(items[l], c) < 0) l++;
 		while ((r>m) && compare_keys(items[r], c) > 0) r--;
 		if (l < r) {
-			ht_data *t;
+			Object *t;
 			t=items[l];
 			items[l]=items[r];
 			items[r]=t;
@@ -1205,16 +1205,16 @@ void ht_sorted_list::done()
 	ht_clist::done();
 }
 
-void ht_sorted_list::append(ht_data *data)
+void ht_sorted_list::append(Object *data)
 {
 	insert(data);
 }
 
-UINT ht_sorted_list::find(ht_data *data)
+uint ht_sorted_list::find(Object *data)
 {
 	if (compare_keys) {
 		HT_ERROR("function untested !");
-		UINT w=(c_entry_count-1)/2, ow=0;
+		uint w=(c_entry_count-1)/2, ow=0;
 		while (w!=ow) {
 			ow=w;
 			int ck=compare_keys(data, items[w]);
@@ -1226,7 +1226,7 @@ UINT ht_sorted_list::find(ht_data *data)
 	return LIST_UNDEFINED;
 }
 
-void ht_sorted_list::insert(ht_data *data)
+void ht_sorted_list::insert(Object *data)
 {
 	if (c_entry_count) {
 		int l=0, r=c_entry_count-1;
@@ -1243,32 +1243,32 @@ void ht_sorted_list::insert(ht_data *data)
 	}
 }
 
-void ht_sorted_list::insert_after(ht_data *data, UINT i)
+void ht_sorted_list::insert_after(Object *data, uint i)
 {
 	insert(data);
 }
 
-void ht_sorted_list::insert_before(ht_data *data, UINT i)
+void ht_sorted_list::insert_before(Object *data, uint i)
 {
 	insert(data);
 }
 
-void ht_sorted_list::move(UINT source, UINT dest)
+void ht_sorted_list::move(uint source, uint dest)
 {
 	// do nothing
 }
 
-void ht_sorted_list::move_multiple(UINT source, UINT dest, UINT count)
+void ht_sorted_list::move_multiple(uint source, uint dest, uint count)
 {
 	// do nothing
 }
 
-void ht_sorted_list::prepend(ht_data *data)
+void ht_sorted_list::prepend(Object *data)
 {
 	insert(data);
 }
 
-bool ht_sorted_list::set(UINT i, ht_data *data)
+bool ht_sorted_list::set(uint i, Object *data)
 {
 	insert(data);
 	return true;
@@ -1278,17 +1278,17 @@ bool ht_sorted_list::set(UINT i, ht_data *data)
  *	CLASS ht_stack
  */
 
-ht_data *ht_stack::pop()
+Object *ht_stack::pop()
 {
 	if (c_entry_count) {
-		ht_data *d=get(c_entry_count-1);
+		Object *d=get(c_entry_count-1);
 		do_remove(c_entry_count-1);
 		return d;
 	}
 	return NULL;
 }
 
-void ht_stack::push(ht_data *data)
+void ht_stack::push(Object *data)
 {
 	append(data);
 }
@@ -1297,27 +1297,27 @@ void ht_stack::push(ht_data *data)
  *	CLASS ht_queue
  */
 
-void	ht_queue::enqueue(ht_data *data)
+void	ht_queue::enqueue(Object *data)
 {
 	append(data);
 }
 
-ht_data *ht_queue::dequeue()
+Object *ht_queue::dequeue()
 {
 	if (c_entry_count) {
-		ht_data *d=get(0);
+		Object *d=get(0);
 		do_remove(0);
 		return d;
 	}
 	return NULL;
 }
 
-ht_data *ht_queue::pop()
+Object *ht_queue::pop()
 {
 	return dequeue();
 }
 
-void	ht_queue::push(ht_data *data)
+void	ht_queue::push(Object *data)
 {
 	enqueue(data);
 }
@@ -1341,12 +1341,12 @@ char *matchhash(int value, int_hash *hash_table)
  *	compare procedures
  */
 
-int compare_keys_ht_data(ht_data *key_a, ht_data *key_b)
+int compare_keys_ht_data(Object *key_a, Object *key_b)
 {
 	return key_a->compareTo(key_b);
 }
 
-int compare_keys_int(ht_data *key_a, ht_data *key_b)
+int compare_keys_int(Object *key_a, Object *key_b)
 {
 	int a=((ht_data_uint*)key_a)->value;
 	int b=((ht_data_uint*)key_b)->value;
@@ -1354,10 +1354,10 @@ int compare_keys_int(ht_data *key_a, ht_data *key_b)
 	return 0;
 }
 
-int compare_keys_uint(ht_data *key_a, ht_data *key_b)
+int compare_keys_uint(Object *key_a, Object *key_b)
 {
-	UINT a=((ht_data_uint*)key_a)->value;
-	UINT b=((ht_data_uint*)key_b)->value;
+	uint a=((ht_data_uint*)key_a)->value;
+	uint b=((ht_data_uint*)key_b)->value;
 	if (a>b) return 1; else if (a<b) return -1;
 	return 0;
 }
@@ -1367,7 +1367,7 @@ int compare_keys_uint(ht_data *key_a, ht_data *key_b)
  */
  
 BUILDER(ATOM_HT_DATA_UINT, ht_data_uint);
-BUILDER(ATOM_HT_DATA_DWORD, ht_data_dword);
+BUILDER(ATOM_HT_DATA_UINT32, ht_data_uint32);
 BUILDER(ATOM_HT_DATA_MEM, ht_data_mem);
 BUILDER(ATOM_HT_STREE, ht_stree);
 BUILDER(ATOM_HT_CLIST, ht_clist);
@@ -1375,7 +1375,7 @@ BUILDER(ATOM_HT_CLIST, ht_clist);
 bool init_data()
 {
 	REGISTER(ATOM_HT_DATA_UINT, ht_data_uint);
-	REGISTER(ATOM_HT_DATA_DWORD, ht_data_dword);
+	REGISTER(ATOM_HT_DATA_UINT32, ht_data_uint32);
 	REGISTER(ATOM_HT_DATA_MEM, ht_data_mem);
 	REGISTER(ATOM_HT_STREE, ht_stree);
 	REGISTER(ATOM_HT_CLIST, ht_clist);
@@ -1398,7 +1398,7 @@ void done_data()
 	unregister_atom(ATOM_COMPARE_KEYS_UINT);
 	
 	UNREGISTER(ATOM_HT_DATA_UINT, ht_data_uint);
-	UNREGISTER(ATOM_HT_DATA_DWORD, ht_data_dword);
+	UNREGISTER(ATOM_HT_DATA_UINT32, ht_data_uint32);
 	UNREGISTER(ATOM_HT_DATA_MEM, ht_data_mem);
 	UNREGISTER(ATOM_HT_STREE, ht_stree);
 	UNREGISTER(ATOM_HT_CLIST, ht_clist);
