@@ -2,7 +2,7 @@
  *	HT Editor
  *	htdialog.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -845,7 +845,7 @@ void ht_strinputfield::handlemsg(htmsg *msg)
 				dirtyview();
 				clearmsg(msg);
 				return;
-			case K_BackSpace:
+			case K_Backspace:
 				if (is_virgin) {
 					is_virgin=0;
 					*selstart=0;
@@ -1153,7 +1153,7 @@ void ht_hexinputfield::handlemsg(htmsg *msg)
 				dirtyview();
 				clearmsg(msg);
 				return;
-			case K_BackSpace:
+			case K_Backspace:
 				if (*textlen) {
 					if (*curchar+nib>*text) {
 /*						if (*curchar-*text<*textlen) {
@@ -1422,7 +1422,7 @@ void ht_listbox_title::update()
  *	CLASS ht_listbox
  */
 
-class ht_listbox_vstate: public ht_data {
+class ht_listbox_vstate: public Object {
 public:
 	void *e_top;
 	void *e_cursor;
@@ -1489,7 +1489,7 @@ void ht_listbox::adjustScrollbar()
 {
 	int pstart, psize;
 	if (scrollbar_pos(pos-cursor, size.h, cached_count, &pstart, &psize)) {
-     	mScrollbarEnabled = true;
+		mScrollbarEnabled = true;
 		scrollbar->enable();
 		bounds c = size;
 		c.x = c.w-1;
@@ -1498,7 +1498,7 @@ void ht_listbox::adjustScrollbar()
 		scrollbar->setbounds(&c);
 		scrollbar->setpos(pstart, psize);
 	} else {
-     	mScrollbarEnabled = false;
+		mScrollbarEnabled = false;
 		scrollbar->disable();
 	}
 }
@@ -1808,7 +1808,7 @@ void ht_listbox::handlemsg(htmsg *msg)
 					}
 				}
 				break;
-			case K_BackSpace: {
+			case K_Backspace: {
 				if (listboxcaps & LISTBOX_QUICKFIND) {
 					if (qpos > quickfinder) {
 						*(--qpos) = 0;
@@ -1901,14 +1901,14 @@ void ht_listbox::setdata(ht_object_stream *s)
 	update();
 }
 
-ht_data *ht_listbox::vstate_create()
+Object *ht_listbox::vstate_create()
 {
 	return new ht_listbox_vstate(e_top, e_cursor);
 }
 
 void ht_listbox::vstate_save()
 {
-	ht_data *vs = vstate_create();
+	Object *vs = vstate_create();
 	if (vs) {
 		htmsg m;
 		m.msg = msg_vstate_save;
