@@ -2,7 +2,7 @@
  *	HT Editor
  *	htdialog.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -43,7 +43,7 @@
 #define button_all			3
 #define button_none			4
 
-class ht_queued_msg: public ht_data {
+class ht_queued_msg: public Object {
 public:
 	ht_view *target;
 	htmsg msg;
@@ -301,7 +301,7 @@ public:
 	int		*widths;
 	
 	ht_scrollbar *scrollbar;
-     bool		mScrollbarEnabled;
+	bool		mScrollbarEnabled;
 	ht_listbox_title *title;
 
 public:
@@ -338,7 +338,7 @@ public:
 	virtual	void		stateChanged();
 	virtual	void		update();
 			void		updateCursor();
-	virtual	ht_data *	vstate_create();
+	virtual	Object *	vstate_create();
 			void		vstate_save();
 protected:
 			void		rearrangeColumns();
@@ -605,7 +605,7 @@ public:
  *	CLASS ht_listbox_ptr
  */
 
-class ht_listbox_ptr: public ht_data {
+class ht_listbox_ptr: public Object {
 public:
 	ht_listbox *listbox;
 
