@@ -2,7 +2,7 @@
  *	HT Editor
  *	htelf.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -69,12 +69,24 @@
 #define ATOM_ELF_ST_TYPE_STR			 "454c460a"
 
 #define ATOM_ELF_R_386_TYPE 			0x454c460b
-#define ATOM_ELF_R_386_TYPE_STR		 "454c460b"
+#define ATOM_ELF_R_386_TYPE_STR		 	 "454c460b"
 
 extern format_viewer_if htelf_if;
 
+class sectionAndIdx: public Object {
+public:
+	uint secidx;
+	uint symidx;
+
+	sectionAndIdx(uint asecidx, uint asymidx)
+	{
+		secidx = asecidx;
+		symidx = asymidx;
+	}
+};
+
 struct elf_section_headers {
-	UINT count;
+	uint count;
 	union {
 		ELF_SECTION_HEADER32 *sheaders32;
 		ELF_SECTION_HEADER64 *sheaders64;
@@ -87,16 +99,16 @@ union elf_section_header {
 };
 
 struct elf_program_headers {
-	UINT count;
+	uint count;
 	union {
 		ELF_PROGRAM_HEADER32 *pheaders32;
 		ELF_PROGRAM_HEADER64 *pheaders64;
 	};
 };
 
-struct ht_elf_reloc_section {
-	elf32_addr address;
-	UINT reloc_shidx;
+struct ht_elf_reloc_section32 {
+	elf32_addr	relocAddr;
+	uint		relocShIdx;
 };
 
 struct ht_elf_shared_data {
@@ -108,75 +120,75 @@ struct ht_elf_shared_data {
 		ELF_HEADER64 header64;
 	};
 	elf_section_headers sheaders;
+	ht_elf_reloc_section32 *shrelocs;
 	char **shnames;
 	elf_program_headers pheaders;
-	UINT symtables;
-	UINT reloctables;
+	uint symtables;
+	uint reloctables;
 	ht_format_viewer *v_image;
-	ht_elf_reloc_section *htrelocs;
-	UINT fake_undefined_section;
+	int fake_undefined_shidx;
+	uint fake_undefined_size;
+	ht_tree *undefined2fakeaddr;
 };
 
 /*
- *	CLASS ht_elf
+ *	ht_elf
  */
-
 class ht_elf: public ht_format_group {
 protected:
 	bool loc_enum;
-/* new */
-			void auto_relocate();
-			void fake_undefined_symbols();
-			UINT find_reloc_section_for(UINT si);
-			void relocate_section(ht_reloc_file *f, UINT si, UINT rsi, elf32_addr a);
+	/* new */
+		void auto_relocate32();
+		void fake_undefined_symbols32();
+		uint find_reloc_section_for(UINT si);
+		void relocate_section(ht_reloc_file *f, uint si, uint rsi, elf32_addr a);
 public:
-			void init(bounds *b, ht_streamfile *file, format_viewer_if **ifs, ht_format_group *format_group, FILEOFS header_ofs);
+		void init(bounds *b, ht_streamfile *file, format_viewer_if **ifs, ht_format_group *format_group, FILEOFS header_ofs);
 	virtual	void done();
-/* overwritten */
+	/* extends ? */
 	virtual	void loc_enum_start();
 	virtual	bool loc_enum_next(ht_format_loc *loc);
 };
 
 /*
- *	CLASS ht_elf32_reloc_entry
+ *	ht_elf32_reloc_entry
  */
 
-class ht_elf32_reloc_entry: public ht_data {
+class ht_elf32_reloc_entry: public Object {
 public:
-	UINT	type;
+	uint	type;
 	union {
-		dword r_32;
-		dword r_pc32;
+		uint32 r_32;
+		uint32 r_pc32;
 	} relocs;
-	
-	ht_elf32_reloc_entry(UINT symtabidx, elf32_addr offset, UINT type, UINT symbolidx, elf32_addr addend, ht_elf_shared_data *data, ht_streamfile *file);
+
+	ht_elf32_reloc_entry(uint type, uint32 A, uint32 P, uint32 S);
 };
 
 /*
- *	CLASS ht_elf32_reloc_file
+ *	ht_elf32_reloc_file
  */
 
 class ht_elf32_reloc_file: public ht_reloc_file {
 protected:
 	ht_elf_shared_data *data;
-/* overwritten */
-	virtual void	reloc_apply(ht_data *reloc, byte *data);
-	virtual bool	reloc_unapply(ht_data *reloc, byte *data);
+	/* extends ht_reloc_file */
+	virtual void	reloc_apply(Object *reloc, byte *data);
+	virtual bool	reloc_unapply(Object *reloc, byte *data);
 public:
 		   void	init(ht_streamfile *streamfile, bool own_streamfile, ht_elf_shared_data *data);
 };
 
+bool isValidELFSectionIdx(ht_elf_shared_data *elf_shared, int idx);
+
 bool elf_phys_and_mem_section(elf_section_header *s, UINT elfclass);
 bool elf_valid_section(elf_section_header *s, UINT elfclass);
 
 bool elf_addr_to_section(elf_section_headers *section_headers, UINT elfclass, ELFAddress addr, int *section);
 bool elf_addr_to_ofs(elf_section_headers *section_headers, UINT elfclass, ELFAddress addr, dword *ofs);
 bool elf_addr_is_valid(elf_section_headers *section_headers, UINT elfclass, ELFAddress addr);
-//bool elf_addr_is_physical(elf_section_headers *section_headers, UINT elfclass, ADDR addr);
 
 bool elf_ofs_to_addr(elf_section_headers *section_headers, UINT elfclass, dword ofs, ELFAddress *addr);
 bool elf_ofs_to_section(elf_section_headers *section_headers, UINT elfclass, dword ofs, dword *section);
-//bool elf_ofs_to_addr_and_section(elf_section_headers *section_headers, UINT elfclass, dword ofs, ELFAddress *addr, int *section);
 
 #endif /* !__HTELF_H__ */
-
