@@ -2,7 +2,7 @@
  *	HT Editor
  *	htelfphs.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -24,46 +24,47 @@
 #include "htelfphs.h"
 #include "httag.h"
 #include "formats.h"
+#include "snprintf.h"
 
-ht_mask_ptable elfprogramheader32[]=
+static ht_mask_ptable elfprogramheader32[]=
 {
-	{"type",				STATICTAG_EDIT_DWORD_VE("00000000")" ("STATICTAG_DESC_DWORD_VE("00000000", ATOM_ELF_PH_TYPE_STR)")"},
-	{"offset",			STATICTAG_EDIT_DWORD_VE("00000004")},
-	{"virtual address",		STATICTAG_EDIT_DWORD_VE("00000008")},
+	{"type",		STATICTAG_EDIT_DWORD_VE("00000000")" ("STATICTAG_DESC_DWORD_VE("00000000", ATOM_ELF_PH_TYPE_STR)")"},
+	{"offset",		STATICTAG_EDIT_DWORD_VE("00000004")},
+	{"virtual address",	STATICTAG_EDIT_DWORD_VE("00000008")},
 	{"physical address",	STATICTAG_EDIT_DWORD_VE("0000000c")},
-	{"in file size",		STATICTAG_EDIT_DWORD_VE("00000010")},
-	{"in memory size",		STATICTAG_EDIT_DWORD_VE("00000014")},
-	{"flags",				STATICTAG_EDIT_DWORD_VE("00000018")" "STATICTAG_FLAGS("00000018", ATOM_ELF_PH_FLAGS_STR)},
-	{"alignment",			STATICTAG_EDIT_DWORD_VE("0000001c")},
+	{"in file size",	STATICTAG_EDIT_DWORD_VE("00000010")},
+	{"in memory size",	STATICTAG_EDIT_DWORD_VE("00000014")},
+	{"flags",		STATICTAG_EDIT_DWORD_VE("00000018")" "STATICTAG_FLAGS("00000018", ATOM_ELF_PH_FLAGS_STR)},
+	{"alignment",		STATICTAG_EDIT_DWORD_VE("0000001c")},
 	{0, 0}
 };
 
-ht_mask_ptable elfprogramheader64[]=
+static ht_mask_ptable elfprogramheader64[]=
 {
-	{"type",				STATICTAG_EDIT_DWORD_VE("00000000")" ("STATICTAG_DESC_DWORD_VE("00000000", ATOM_ELF_PH_TYPE_STR)")"},
-	{"flags",				STATICTAG_EDIT_DWORD_VE("00000004")" "STATICTAG_FLAGS("00000004", ATOM_ELF_PH_FLAGS_STR)},
-	{"offset",			STATICTAG_EDIT_QWORD_VE("00000008")},
-	{"virtual address",		STATICTAG_EDIT_QWORD_VE("00000010")},
+	{"type",		STATICTAG_EDIT_DWORD_VE("00000000")" ("STATICTAG_DESC_DWORD_VE("00000000", ATOM_ELF_PH_TYPE_STR)")"},
+	{"flags",		STATICTAG_EDIT_DWORD_VE("00000004")" "STATICTAG_FLAGS("00000004", ATOM_ELF_PH_FLAGS_STR)},
+	{"offset",		STATICTAG_EDIT_QWORD_VE("00000008")},
+	{"virtual address",	STATICTAG_EDIT_QWORD_VE("00000010")},
 	{"physical address",	STATICTAG_EDIT_QWORD_VE("00000018")},
-	{"in file size",		STATICTAG_EDIT_QWORD_VE("00000020")},
-	{"in memory size",		STATICTAG_EDIT_QWORD_VE("00000028")},
-	{"alignment",			STATICTAG_EDIT_QWORD_VE("00000030")},
+	{"in file size",	STATICTAG_EDIT_QWORD_VE("00000020")},
+	{"in memory size",	STATICTAG_EDIT_QWORD_VE("00000028")},
+	{"alignment",		STATICTAG_EDIT_QWORD_VE("00000030")},
 	{0, 0}
 };
 
-int_hash elf_ph_type[] =
+static int_hash elf_ph_type[] =
 {
 	{ELF_PT_NULL, 		"null"},
 	{ELF_PT_LOAD,		"load"},
 	{ELF_PT_DYNAMIC,	"dynamic"},
-	{ELF_PT_INTERP,	"interp"},
+	{ELF_PT_INTERP,		"interp"},
 	{ELF_PT_NOTE,		"note"},
 	{ELF_PT_SHLIB,		"shlib"},
 	{ELF_PT_PHDR,		"phdr"},
 	{0, 0}
 };
 
-ht_tag_flags_s elf_ph_flags[] =
+static ht_tag_flags_s elf_ph_flags[] =
 {
 	{0,  "[00] executable"},
 	{1,  "[01] writable"},
@@ -71,7 +72,7 @@ ht_tag_flags_s elf_ph_flags[] =
 	{0, 0}
 };
 
-ht_view *htelfprogramheaders_init(bounds *b, ht_streamfile *file, ht_format_group *group)
+static ht_view *htelfprogramheaders_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 {
 	ht_elf_shared_data *elf_shared=(ht_elf_shared_data *)group->get_shared_data();
 
@@ -90,7 +91,7 @@ ht_view *htelfprogramheaders_init(bounds *b, ht_streamfile *file, ht_format_grou
 		m->init(file, 0);
 	
 		char info[128];
-		sprintf(info, "* ELF program headers at offset %08x", h);
+		ht_snprintf(info, sizeof info, "* ELF program headers at offset %08x", h);
 	
 		m->add_mask(info);
 
@@ -103,7 +104,7 @@ ht_view *htelfprogramheaders_init(bounds *b, ht_streamfile *file, ht_format_grou
 			char t[32];
 			char *etype=matchhash(elf_shared->pheaders.pheaders32[i].p_type, elf_ph_type);
 			if (!etype) etype="?";
-			sprintf(t, "entry %d (%s)", i, etype);
+			ht_snprintf(t, sizeof t, "entry %d (%s)", i, etype);
 		
 			n->add_staticmask_ptable(elfprogramheader32, h+i*elf_shared->header32.e_phentsize, elf_bigendian);
 		
@@ -126,7 +127,7 @@ ht_view *htelfprogramheaders_init(bounds *b, ht_streamfile *file, ht_format_grou
 		m->init(file, 0);
 	
 		char info[128];
-		sprintf(info, "* ELF program headers at offset %08x", h);
+		ht_snprintf(info, sizeof info, "* ELF program headers at offset %08x", h);
 	
 		m->add_mask(info);
 
@@ -139,7 +140,7 @@ ht_view *htelfprogramheaders_init(bounds *b, ht_streamfile *file, ht_format_grou
 			char t[32];
 			char *etype=matchhash(elf_shared->pheaders.pheaders64[i].p_type, elf_ph_type);
 			if (!etype) etype="?";
-			sprintf(t, "entry %d (%s)", i, etype);
+			ht_snprintf(t, sizeof t, "entry %d (%s)", i, etype);
 		
 			n->add_staticmask_ptable(elfprogramheader64, h+i*elf_shared->header64.e_phentsize, elf_bigendian);
 		
