@@ -2,7 +2,7 @@
  *	HT Editor
  *	htelfrel.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -28,7 +28,7 @@
 
 #include <stdlib.h>
 
-int_hash elf_r_386_type[] =
+static int_hash elf_r_386_type[] =
 {
 	{ELF_R_386_NONE,		"ELF_R_386_NONE"},
 	{ELF_R_386_32,			"ELF_R_386_32"},
@@ -44,13 +44,13 @@ int_hash elf_r_386_type[] =
 	{0, 0}
 };
 
-ht_view *htelfreloctable_init(bounds *b, ht_streamfile *file, ht_format_group *group)
+static ht_view *htelfreloctable_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 {
 	ht_elf_shared_data *elf_shared=(ht_elf_shared_data *)group->get_shared_data();
 
 	if ((elf_shared->ident.e_ident[ELF_EI_CLASS]!=ELFCLASS32) ||
 	(elf_shared->ident.e_ident[ELF_EI_DATA]!=ELFDATA2LSB) ||
-	(elf_shared->header32.e_machine!=ELF_EM_386)) return 0;
+	(elf_shared->header32.e_machine!=ELF_EM_386)) return NULL;
 	
 	UINT skip = elf_shared->reloctables;
 	UINT reloctab_shidx = ELF_SHN_UNDEF;
@@ -64,20 +64,24 @@ ht_view *htelfreloctable_init(bounds *b, ht_streamfile *file, ht_format_group *g
 			}
 		}
 	}
-	if (reloctab_shidx==ELF_SHN_UNDEF) return 0;
+	if (!isValidELFSectionIdx(elf_shared, reloctab_shidx)) return NULL;
 
 	FILEOFS h=elf_shared->sheaders.sheaders32[reloctab_shidx].sh_offset;
 	
-/* section index of associated symbol table */
+	/* section index of associated symbol table */
 	int si_symbol=elf_shared->sheaders.sheaders32[reloctab_shidx].sh_link;
 	
-/* section index of section to be relocated */
+	/* section index of section to be relocated */
 	int si_dest=elf_shared->sheaders.sheaders32[reloctab_shidx].sh_info;
 
-	file->seek(elf_shared->sheaders.sheaders32[elf_shared->header32.e_shstrndx].sh_offset+elf_shared->sheaders.sheaders32[reloctab_shidx].sh_name);
-	char *reloctab_name=fgetstrz(file);
+	char *reloctab_name;
+	if (!isValidELFSectionIdx(elf_shared, elf_shared->header32.e_shstrndx)
+	|| file->seek(elf_shared->sheaders.sheaders32[elf_shared->header32.
+	e_shstrndx].sh_offset+elf_shared->sheaders.sheaders32[reloctab_shidx].sh_name)
+	|| !((reloctab_name=fgetstrz(file))))
+		reloctab_name = "?";
 	char desc[128];
-	sprintf(desc, DESC_ELF_RELOCTAB, reloctab_name, reloctab_shidx);
+	ht_snprintf(desc, sizeof desc, DESC_ELF_RELOCTAB, reloctab_name, reloctab_shidx);
 	free(reloctab_name);
 	
 	ht_uformat_viewer *v=new ht_uformat_viewer();
@@ -157,4 +161,3 @@ format_viewer_if htelfreloctable_if = {
 	htelfreloctable_init,
 	0
 };
-
