@@ -2,7 +2,7 @@
  *	HT Editor
  *	htfinfo.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -77,9 +77,11 @@ char *ht_finfo_text::gettext()
 	if (s.caps & pstat_gid) t+=sprintf(t, "%-"FINFO_IDENTIFIER_WIDTH_STR"s%d\n", "group id", s.gid);
 
 	if (s.caps & pstat_size) {
-		t+=sprintf(t, "%-"FINFO_IDENTIFIER_WIDTH_STR"s%d (%.2fK, %.2fM)\n", "size", s.size, ((float)s.size)/1024, ((float)s.size)/1024/1024);
+		t+=sprintf(t, "%-"FINFO_IDENTIFIER_WIDTH_STR"s%d (%.2f KiB, %.2f MiB)"
+		" / 0x%08x\n", "size", s.size, ((float)s.size)/1024,
+		((float)s.size)/1024/1024, s.size);
 	}	    
-	
+
 	if (s.caps & pstat_inode) t+=sprintf(t, "%-"FINFO_IDENTIFIER_WIDTH_STR"s%d\n", "inode", s.fsid); else
 		if (s.caps & pstat_cluster) t+=sprintf(t, "%-"FINFO_IDENTIFIER_WIDTH_STR"s%d\n", "cluster (?)", s.fsid); else
 		if (s.caps & pstat_fsid) t+=sprintf(t, "%-"FINFO_IDENTIFIER_WIDTH_STR"s%d\n", "fsid", s.fsid);
