@@ -2,7 +2,7 @@
  *	HT Editor
  *	htformat.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -56,7 +56,7 @@ union viewer_pos {
  *	CLASS ht_search_request
  */
  
-class ht_search_request: public ht_data {
+class ht_search_request: public Object {
 public:
 	UINT search_class;
 	UINT type;
@@ -69,7 +69,7 @@ public:
  *	CLASS ht_search_result
  */
  
-class ht_search_result: public ht_data {
+class ht_search_result: public Object {
 public:
 	UINT search_class;
 
@@ -105,7 +105,7 @@ public:
  *	formats
  */
 
-class ht_format_loc: public ht_data {
+class ht_format_loc: public Object {
 public:
 	char *name;
 	FILEOFS start;
@@ -155,8 +155,8 @@ protected:
 /* new */
 	virtual	bool compeq_viewer_pos(viewer_pos *a, viewer_pos *b);
 
-	virtual	void vstate_restore(ht_data *view_state);
-	virtual	ht_data *vstate_create();
+	virtual	void vstate_restore(Object *view_state);
+	virtual	Object *vstate_create();
 	
 	virtual	bool next_logical_pos(viewer_pos pos, viewer_pos *npos);
 	virtual	bool next_logical_offset(FILEOFS ofs, FILEOFS *nofs);
@@ -223,7 +223,7 @@ public:
  *	CLASS ht_format_viewer_entry
  */
 
-class ht_format_viewer_entry: public ht_data {
+class ht_format_viewer_entry: public Object {
 public:
 	ht_view *instance;
 	format_viewer_if *interface;
@@ -324,8 +324,8 @@ protected:
 	virtual	char *func(UINT i, bool execute);
 	virtual	bool next_logical_pos(viewer_pos pos, viewer_pos *npos);
 	virtual	bool next_logical_offset(FILEOFS ofs, FILEOFS *nofs);
-	virtual	ht_data *vstate_create();
-	virtual	void vstate_restore(ht_data *view_state);
+	virtual	Object *vstate_create();
+	virtual	void vstate_restore(Object *view_state);
 /* new */
 	int address_input(const char *title, char *buf, int buflen, dword histid);
 	void adjust_cursor_group();
