@@ -2,7 +2,7 @@
  *	HT Editor
  *	hthist.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -132,7 +132,7 @@ OBJECT_ID ht_history_entry::object_id() const
 	return ATOM_HT_HISTORY_ENTRY;
 }
 
-int compare_keys_history_entry(ht_data *key_a, ht_data *key_b)
+int compare_keys_history_entry(Object *key_a, Object *key_b)
 {
     return strcmp(((ht_history_entry*)key_a)->desc, ((ht_history_entry*)key_b)->desc);
 }
