@@ -2,7 +2,7 @@
  *	HT Editor
  *	hthist.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -43,7 +43,7 @@
  *	CLASS ht_history_entry
  */
 
-class ht_history_entry: public ht_data {
+class ht_history_entry: public Object {
 public:
 	char *desc;
 	ht_object_stream_bin *data;
