@@ -2,7 +2,7 @@
  *	HT Editor
  *	htle.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -38,7 +38,7 @@
 #define LE_SEG_ADDR(i) (LE_shared->objmap.header[(i)].page_map_index-1) *\
 			LE_shared->hdr.pagesize + LE_BASE_ADDR
 
-format_viewer_if *htle_ifs[] = {
+static format_viewer_if *htle_ifs[] = {
 	&htleheader_if,
 	&htlevxd_if,
 	&htlepagemaps_if,
@@ -48,7 +48,7 @@ format_viewer_if *htle_ifs[] = {
 	0
 };
 
-ht_view *htle_init(bounds *b, ht_streamfile *file, ht_format_group *format_group)
+static ht_view *htle_init(bounds *b, ht_streamfile *file, ht_format_group *format_group)
 {
 	byte lemagic[2];
 	FILEOFS h=get_newexe_header_ofs(file);
@@ -475,11 +475,12 @@ bool ht_le_page_file::unmap_ofs(FILEOFS pofs, UINT *lofs)
 	return false;
 }
 
-UINT ht_le_page_file::read(void *buf, UINT size)
+UINT ht_le_page_file::read(void *aBuf, UINT size)
 {
 	FILEOFS mofs;
 	UINT msize;
 	int c = 0;
+	byte *buf = (byte *)aBuf;
 	while (size) {
 		UINT s = size;
 		if (!map_ofs(ofs, &mofs, &msize)) break;
@@ -487,7 +488,7 @@ UINT ht_le_page_file::read(void *buf, UINT size)
 		streamfile->seek(mofs);
 		s = streamfile->read(buf, s);
 		if (!s) break;
-		((byte*)buf) += s;
+		buf += s;
 		size -= s;
 		c += s;
 		ofs += s;
@@ -546,17 +547,18 @@ int ht_le_page_file::vcntl(UINT cmd, va_list vargs)
 	return ht_layer_streamfile::vcntl(cmd, vargs);
 }
 
-UINT ht_le_page_file::write(const void *buf, UINT size)
+UINT ht_le_page_file::write(const void *aBuf, UINT size)
 {
 	FILEOFS mofs;
 	UINT msize;
 	int c = 0;
+	const byte *buf = (const byte *)aBuf;
 	while (size) {
 		UINT s = size;
 		if (!map_ofs(ofs, &mofs, &msize)) break;
 		if (s>msize) s = msize;
 		streamfile->seek(mofs);
-		((byte*)buf) += streamfile->write(buf, s);
+		buf += streamfile->write(buf, s);
 		size -= s;
 		c += s;
 		ofs += s;
@@ -587,7 +589,7 @@ void ht_le_reloc_file::init(ht_streamfile *s, bool os, ht_le_shared_data *d)
 	data = d;
 }
 
-void ht_le_reloc_file::reloc_apply(ht_data *reloc, byte *data)
+void ht_le_reloc_file::reloc_apply(Object *reloc, byte *data)
 {
 	ht_le_reloc_entry *e = (ht_le_reloc_entry*)reloc;
 
@@ -618,7 +620,7 @@ void ht_le_reloc_file::reloc_apply(ht_data *reloc, byte *data)
 	}
 }
 
-bool ht_le_reloc_file::reloc_unapply(ht_data *reloc, byte *data)
+bool ht_le_reloc_file::reloc_unapply(Object *reloc, byte *data)
 {
 	return false;
 }
