@@ -2,7 +2,7 @@
  *	HT Editor
  *	htle.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -126,7 +126,7 @@ public:
  *	CLASS ht_le_reloc_entry
  */
 
-class ht_le_reloc_entry: public ht_data {
+class ht_le_reloc_entry: public Object {
 public:
 	UINT ofs;	// FIXME: hack
 	UINT seg;
@@ -145,8 +145,8 @@ class ht_le_reloc_file: public ht_reloc_file {
 protected:
 	ht_le_shared_data *data;
 /* overwritten */
-	virtual void	reloc_apply(ht_data *reloc, byte *data);
-	virtual bool	reloc_unapply(ht_data *reloc, byte *data);
+	virtual void	reloc_apply(Object *reloc, byte *data);
+	virtual bool	reloc_unapply(Object *reloc, byte *data);
 public:
 		   void	init(ht_streamfile *streamfile, bool own_streamfile, ht_le_shared_data *data);
 };
