@@ -2,7 +2,7 @@
  *	HT Editor
  *	htlehead.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -23,11 +23,12 @@
 #include "htle.h"
 #include "htlehead.h"
 #include "httag.h"
+#include "snprintf.h"
 #include "formats.h"
 
 #include "lestruct.h"
 
-int_hash le_machines[] =
+static int_hash le_machines[] =
 {
 	{ LE_CPU_286,	"Intel 286" },
 	{ LE_CPU_386,	"Intel 386" },
@@ -41,7 +42,7 @@ int_hash le_machines[] =
 	{0, 0}
 };
 
-int_hash le_os[] =
+static int_hash le_os[] =
 {
 	{ LE_OS_OS2, "OS/2"},
 	{ LE_OS_WIN, "Windows"},
@@ -50,7 +51,7 @@ int_hash le_os[] =
 	{0, 0}
 };
 
-ht_tag_flags_s le_flags[] =
+static ht_tag_flags_s le_flags[] =
 {
 	{-1, "LE - module flags"},
 	{0,  "[00] ?"},
@@ -72,7 +73,7 @@ ht_tag_flags_s le_flags[] =
 	{0, 0}
 };
 
-ht_mask_ptable leheader[]=
+static ht_mask_ptable leheader[]=
 {
 	{"magic",							STATICTAG_EDIT_WORD_LE("00000000")},
 	{"byte order",						STATICTAG_EDIT_BYTE("00000002")},
@@ -131,7 +132,7 @@ ht_mask_ptable leheader[]=
 	{0, 0}
 };
 
-ht_view *htleheader_init(bounds *b, ht_streamfile *file, ht_format_group *group)
+static ht_view *htleheader_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 {
 	ht_le_shared_data *le_shared=(ht_le_shared_data *)group->get_shared_data();
 
@@ -149,7 +150,7 @@ ht_view *htleheader_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 	register_atom(ATOM_LE_OS, le_os);
 
 	char info[128];
-	sprintf(info, "* LE header at offset %08x", le_shared->hdr_ofs);
+	ht_snprintf(info, sizeof info, "* LE header at offset %08x", le_shared->hdr_ofs);
 	m->add_mask(info);
 	m->add_staticmask_ptable(leheader, h, le_bigendian);
 	v->insertsub(m);
