@@ -2,7 +2,7 @@
  *	HT Editor
  *	htleimg.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -32,7 +32,7 @@
 #include "htanaly.h"
 #include "le_analy.h"
 
-ht_view *htleimage_init(bounds *b, ht_streamfile *file, ht_format_group *group)
+static ht_view *htleimage_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 {
 	ht_le_shared_data *le_shared=(ht_le_shared_data *)group->get_shared_data();
 
@@ -164,4 +164,3 @@ void ht_le_aviewer::setAnalyser(Analyser *a)
 	analy = a;
 	analy_sub->setAnalyser(a);
 }
-
