@@ -2,7 +2,7 @@
  *	HT Editor
  *	htlepage.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -24,12 +24,13 @@
 #include "httag.h"
 #include "htstring.h"
 #include "formats.h"
+#include "snprintf.h"
 
 #include "lestruct.h"
 
 #include <stdlib.h>
 
-ht_mask_ptable lepagemap[]=
+static ht_mask_ptable lepagemap[]=
 {
 	{"page high",	STATICTAG_EDIT_WORD_LE("00000000")},
 	{"page low",	STATICTAG_EDIT_BYTE("00000002")},
@@ -37,7 +38,7 @@ ht_mask_ptable lepagemap[]=
 	{0, 0}
 };
 
-ht_view *htlepagemaps_init(bounds *b, ht_streamfile *file, ht_format_group *group)
+static ht_view *htlepagemaps_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 {
 	ht_le_shared_data *le_shared=(ht_le_shared_data *)group->get_shared_data();
 
@@ -49,7 +50,7 @@ ht_view *htlepagemaps_init(bounds *b, ht_streamfile *file, ht_format_group *grou
 	m->init(file, 0);
 
 	char t[64];
-	sprintf(t, "* LE page maps at offset %08x", h+le_shared->hdr.pagemap);
+	ht_snprintf(t, sizeof t, "* LE page maps at offset %08x", h+le_shared->hdr.pagemap);
 	m->add_mask(t);
 
 	v->insertsub(m);
@@ -61,7 +62,7 @@ ht_view *htlepagemaps_init(bounds *b, ht_streamfile *file, ht_format_group *grou
 		m=new ht_mask_sub();
 		m->init(file, i);
 		
-		sprintf(t, "--- page %d at %08x ---", i+1, le_shared->pagemap.offset[i]);
+		ht_snprintf(t, sizeof t, "--- page %d at %08x ---", i+1, le_shared->pagemap.offset[i]);
 		m->add_staticmask_ptable(lepagemap, h+le_shared->hdr.pagemap+i*4, le_bigendian);
 		ht_collapsable_sub *cs=new ht_collapsable_sub();
 		cs->init(file, m, 1, t, 1);
@@ -76,4 +77,3 @@ format_viewer_if htlepagemaps_if = {
 	htlepagemaps_init,
 	0
 };
-
