@@ -2,7 +2,7 @@
  *	HT Editor
  *	htmenu.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -96,7 +96,7 @@ bool execute_submenu(int x, int y, ht_context_menu *m)
 
 void ht_context_menu::init(char *Name)
 {
-	ht_data::init();
+	Object::init();
 	name = ht_strdup(Name);
 	shortcut = shortcut_str(name);
 	width = 0;
@@ -105,7 +105,7 @@ void ht_context_menu::init(char *Name)
 void ht_context_menu::done()
 {
 	free(name);
-	ht_data::done();
+	Object::done();
 }
 
 int ht_context_menu::count()
