@@ -2,7 +2,7 @@
  *	HT Editor
  *	htmenu.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -35,7 +35,7 @@ class ht_context_menu;
 #define CME_SEPARATOR	1
 #define CME_SUBMENU		2
 
-class ht_context_menu_entry: public ht_data {
+class ht_context_menu_entry: public Object {
 public:
 	int type;
 	union {
@@ -57,7 +57,7 @@ public:
  *	CLASS ht_context_menu
  */
 
-class ht_context_menu: public ht_data {
+class ht_context_menu: public Object {
 private:
 	char *name;
 	char *shortcut;
