@@ -2,7 +2,7 @@
  *	HT Editor
  *	htmzhead.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -22,8 +22,9 @@
 #include "htmzhead.h"
 #include "httag.h"
 #include "formats.h"
+#include "snprintf.h"
 
-ht_mask_ptable mzheader[]=
+static ht_mask_ptable mzheader[]=
 {
 	{"magic",							STATICTAG_EDIT_WORD_LE("00000000")},
 	{"bytes on last page of file",		STATICTAG_EDIT_WORD_LE("00000002")},
@@ -47,14 +48,14 @@ ht_mask_ptable mzheader[]=
 	{0, 0}
 };
 
-ht_view *htmzheader_init(bounds *b, ht_streamfile *file, ht_format_group *group)
+static ht_view *htmzheader_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 {
 	ht_uformat_viewer *v=new ht_uformat_viewer();
 	v->init(b, DESC_MZ_HEADER, VC_EDIT | VC_SEARCH, file, group);
 	ht_mask_sub *m=new ht_mask_sub();
 	m->init(file, 0);
 	char info[128];
-	sprintf(info, "* MZ header at offset %08x (paragraph=16 bytes, page=512 bytes)", 0);	/* FIXME: hmm, seems to be always 0 ?! */
+	ht_snprintf(info, sizeof info, "* MZ header at offset %08x (paragraph=16 bytes, page=512 bytes)", 0);	/* FIXME: hmm, seems to be always 0 ?! */
 	m->add_mask(info);
 	m->add_staticmask_ptable(mzheader, 0, false);
 	v->insertsub(m);
