@@ -2,7 +2,7 @@
  *	HT Editor
  *	htmzimg.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -25,10 +25,11 @@
 #include "htstring.h"
 #include "htformat.h"
 #include "formats.h"
+#include "snprintf.h"
 #include "x86asm.h"
 #include "x86dis.h"
 
-ht_view *htmzimage_init(bounds *b, ht_streamfile *file, ht_format_group *group)
+static ht_view *htmzimage_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 {
 	ht_mz_shared_data *mz_shared=(ht_mz_shared_data *)group->get_shared_data();
 
@@ -41,7 +42,7 @@ ht_view *htmzimage_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 	ht_mask_sub *m=new ht_mask_sub();
 	m->init(file, 0);
 	char info[128];
-	sprintf(info, "* MZ image at offset %08x", o);
+	ht_snprintf(info, sizeof info, "* MZ image at offset %08x", o);
 	m->add_mask(info);
 	v->insertsub(m);
 
