@@ -2,7 +2,7 @@
  *	HT Editor
  *	htmzrel.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -23,8 +23,9 @@
 #include "htpal.h"
 #include "httag.h"
 #include "formats.h"
+#include "snprintf.h"
 
-int htmzrel_detect(ht_streamfile *file)
+static int htmzrel_detect(ht_streamfile *file)
 {
 	word rcount;
 	file->seek(6);
@@ -32,7 +33,7 @@ int htmzrel_detect(ht_streamfile *file)
 	return rcount;
 }
 
-ht_view *htmzrel_init(bounds *b, ht_streamfile *file, ht_format_group *group)
+static ht_view *htmzrel_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 {
 	ht_uformat_viewer *v=new ht_uformat_viewer();
 	v->init(b, DESC_MZ_REL, VC_EDIT | VC_SEARCH, file, group);
@@ -47,7 +48,7 @@ ht_view *htmzrel_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 	ht_mask_sub *m=new ht_mask_sub();
 	m->init(file, 0);
 	char info[128];
-	sprintf(info, "* MZ relocations at offset %08x", r);
+	ht_snprintf(info, sizeof info, "* MZ relocations at offset %08x", r);
 	m->add_mask(info);
 	for (int i=rc; i>0; i--) {
 		int so;
@@ -63,8 +64,3 @@ ht_view *htmzrel_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 	v->insertsub(m);
 	return v;
 }
-
-/*viewer_int htmzrel_int = {
-	htmzrel_detect,
-	htmzrel_init
-};*/
