@@ -2,7 +2,7 @@
  *	HT Editor
  *	htne.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -35,7 +35,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-format_viewer_if *htne_ifs[] = {
+static format_viewer_if *htne_ifs[] = {
 	&htneheader_if,
 	&htnesegments_if,
 	&htneimports_if,
@@ -45,7 +45,7 @@ format_viewer_if *htne_ifs[] = {
 	0
 };
 
-int compare_keys_ne_import_rec(ht_data *key_a, ht_data *key_b)
+static int compare_keys_ne_import_rec(Object *key_a, Object *key_b)
 {
 	ne_import_rec *a=(ne_import_rec*)key_a;
 	ne_import_rec *b=(ne_import_rec*)key_b;
@@ -62,7 +62,7 @@ int compare_keys_ne_import_rec(ht_data *key_a, ht_data *key_b)
 	return a->module - b->module;
 }
 
-ht_view *htne_init(bounds *b, ht_streamfile *file, ht_format_group *format_group)
+static ht_view *htne_init(bounds *b, ht_streamfile *file, ht_format_group *format_group)
 {
 	byte nemagic[2];
 	FILEOFS h = get_newexe_header_ofs(file);
@@ -414,7 +414,7 @@ void ht_ne_reloc_file::init(ht_streamfile *s, bool os, ht_ne_shared_data *d)
 	data = d;
 }
 
-void ht_ne_reloc_file::reloc_apply(ht_data *reloc, byte *data)
+void ht_ne_reloc_file::reloc_apply(Object *reloc, byte *data)
 {
 	ht_ne_reloc_entry *e = (ht_ne_reloc_entry*)reloc;
 
@@ -442,7 +442,7 @@ void ht_ne_reloc_file::reloc_apply(ht_data *reloc, byte *data)
 	}
 }
 
-bool ht_ne_reloc_file::reloc_unapply(ht_data *reloc, byte *data)
+bool ht_ne_reloc_file::reloc_unapply(Object *reloc, byte *data)
 {
 	return false;
 //	ht_ne_reloc_entry *e = (ht_ne_reloc_entry*)reloc;
@@ -522,4 +522,3 @@ bool NE_ofs_to_addr(ht_ne_shared_data *NE_shared, FILEOFS ofs, NEAddress *Addr)
 	}
 	return false;
 }
-
