@@ -2,7 +2,7 @@
  *	HT Editor
  *	htne.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -52,7 +52,7 @@ struct ne_segment_headers {
 	NE_SEGMENT *segments;
 };
 
-class ne_import_rec: public ht_data {
+class ne_import_rec: public Object {
 public:
 	UINT addr;
 	UINT module;
@@ -105,7 +105,7 @@ extern format_viewer_if htne_if;
  *	CLASS ht_ne_entrypoint
  */
 
-class ht_ne_entrypoint: public ht_data {
+class ht_ne_entrypoint: public Object {
 public:
 	UINT ordinal;
 	UINT seg;
@@ -121,7 +121,7 @@ public:
  *	CLASS ht_ne_reloc_entry
  */
 
-class ht_ne_reloc_entry: public ht_data {
+class ht_ne_reloc_entry: public Object {
 public:
 	UINT mode;
 	bool add;
@@ -140,8 +140,8 @@ class ht_ne_reloc_file: public ht_reloc_file {
 protected:
 	ht_ne_shared_data *data;
 /* overwritten */
-	virtual void	reloc_apply(ht_data *reloc, byte *data);
-	virtual bool	reloc_unapply(ht_data *reloc, byte *data);
+	virtual void	reloc_apply(Object *reloc, byte *data);
+	virtual bool	reloc_unapply(Object *reloc, byte *data);
 public:
 		   void	init(ht_streamfile *streamfile, bool own_streamfile, ht_ne_shared_data *data);
 };
