@@ -2,7 +2,7 @@
  *	HT Editor
  *	htneent.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -28,7 +28,7 @@
 #include "formats.h"
 #include "snprintf.h"
 
-ht_tag_flags_s ne_entflags[] =
+static ht_tag_flags_s ne_entflags[] =
 {
 	{-1, "NE - entrypoint flags"},
 	{0,  "[00] exported"},
@@ -37,7 +37,7 @@ ht_tag_flags_s ne_entflags[] =
 	{0, 0}
 };
 
-ht_view *htneentrypoints_init(bounds *b, ht_streamfile *file, ht_format_group *group)
+static ht_view *htneentrypoints_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 {
 	ht_ne_shared_data *ne_shared = (ht_ne_shared_data *)group->get_shared_data();
 
@@ -50,7 +50,7 @@ ht_view *htneentrypoints_init(bounds *b, ht_streamfile *file, ht_format_group *g
 	register_atom(ATOM_NE_ENTFLAGS, ne_entflags);
 
 	char line[1024], *l;	/* possible buffer overflow */
-	sprintf(line, "* NE entrypoint table at offset %08x", h+ne_shared->hdr.enttab);
+	ht_snprintf(line, sizeof line, "* NE entrypoint table at offset %08x", h+ne_shared->hdr.enttab);
 	m->add_mask(line);
 
 	FILEOFS o = h + ne_shared->hdr.enttab;
@@ -73,6 +73,7 @@ ht_view *htneentrypoints_init(bounds *b, ht_streamfile *file, ht_format_group *g
 			ht_snprintf(line, sizeof line, "entrypoints for fixed segment %d [%d entries]", e.seg_index, e.entry_count);
 			m->add_mask(line);
 		}
+		// FIXME: dont use sprintf
 		for (int i=0; i<e.entry_count; i++) {
 			if (e.seg_index==0) {
 			} else if (e.seg_index==0xff) {
@@ -150,4 +151,3 @@ int ht_ne_entrypoint_viewer::ref_sel(LINE_ID *id)
 	return 1;*/
 	return 0;
 }
-
