@@ -2,7 +2,7 @@
  *	HT Editor
  *	htnehead.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -22,8 +22,9 @@
 #include "htne.h"
 #include "httag.h"
 #include "formats.h"
+#include "snprintf.h"
 
-ht_mask_ptable neheader[]=
+static ht_mask_ptable neheader[]=
 {
 	{"magic",							STATICTAG_EDIT_WORD_LE("00000000")},
 	{"version",						STATICTAG_EDIT_BYTE("00000002")},
@@ -58,7 +59,7 @@ ht_mask_ptable neheader[]=
 	{0, 0}
 };
 
-int_hash ne_os[] =
+static int_hash ne_os[] =
 {
 	{NE_OS_UNKNOWN, "all"},
 	{NE_OS_OS2, "OS/2"},
@@ -67,7 +68,7 @@ int_hash ne_os[] =
 	{0, 0}
 };
 
-ht_tag_flags_s ne_flags[] =
+static ht_tag_flags_s ne_flags[] =
 {
 	{-1, "NE - file characteristics"},
 	{0,  "[00] solo data"},
@@ -89,7 +90,7 @@ ht_tag_flags_s ne_flags[] =
 	{0, 0}
 };
 
-ht_view *htneheader_init(bounds *b, ht_streamfile *file, ht_format_group *group)
+static ht_view *htneheader_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 {
 	ht_ne_shared_data *ne_shared=(ht_ne_shared_data *)group->get_shared_data();
 
@@ -103,7 +104,7 @@ ht_view *htneheader_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 	register_atom(ATOM_NE_FLAGS, ne_flags);
 
 	char info[128];
-	sprintf(info, "* NE header at offset %08x", ne_shared->hdr_ofs);
+	ht_snprintf(info, sizeof info, "* NE header at offset %08x", ne_shared->hdr_ofs);
 	m->add_mask(info);
 	m->add_staticmask_ptable(neheader, h, false);
 	v->insertsub(m);
