@@ -2,7 +2,7 @@
  *	HT Editor
  *	htpe.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -49,8 +49,11 @@
 #define ATOM_PE_CHARACTERISTICS			0x50450003
 #define ATOM_PE_CHARACTERISTICS_STR		 "50450003"
 
-#define ATOM_PE_SECTION_CHARACTERISTICS		0x50450004
-#define ATOM_PE_SECTION_CHARACTERISTICS_STR	 "50450004"
+#define ATOM_PE_DLL_CHARACTERISTICS		0x50450004
+#define ATOM_PE_DLL_CHARACTERISTICS_STR		 "50450004"
+
+#define ATOM_PE_SECTION_CHARACTERISTICS		0x50450005
+#define ATOM_PE_SECTION_CHARACTERISTICS_STR	 "50450005"
 
 extern format_viewer_if htpe_if;
 
@@ -83,6 +86,7 @@ struct ht_pe_shared_data {
 	ht_view *v_imports;
 	ht_view *v_dimports;
 	ht_view *v_resources;
+	ht_view *v_il;
 	ht_format_viewer *v_image;	
 };
 
