@@ -2,7 +2,7 @@
  *	HT Editor
  *	htpedimp.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -37,7 +37,7 @@
 
 #include <stdlib.h>
 
-ht_view *htpedelayimports_init(bounds *b, ht_streamfile *file, ht_format_group *group)
+static ht_view *htpedelayimports_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 {
 	ht_pe_shared_data *pe_shared=(ht_pe_shared_data *)group->get_shared_data();
 
