@@ -2,7 +2,7 @@
  *	HT Editor
  *	htpeexp.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -40,7 +40,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-ht_view *htpeexports_init(bounds *b, ht_streamfile *file, ht_format_group *group)
+static ht_view *htpeexports_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 {
 	ht_pe_shared_data *pe_shared=(ht_pe_shared_data *)group->get_shared_data();
 
@@ -352,4 +352,3 @@ ht_pe_export_function::~ht_pe_export_function()
 {
 	if ((byname) && (name)) free(name);
 }
-
