@@ -2,7 +2,7 @@
  *	HT Editor
  *	htpeexp.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -48,7 +48,7 @@ public:
  *	CLASS ht_pe_export_function
  */
 
-class ht_pe_export_function: public ht_data {
+class ht_pe_export_function: public Object {
 public:
 	UINT ordinal;
 
