@@ -2,7 +2,7 @@
  *	HT Editor
  *	htpehead.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -37,7 +37,7 @@
 
 #include <string.h>
 
-int_hash pe_optional_magics[] =
+static int_hash pe_optional_magics[] =
 {
 	{COFF_OPTMAGIC_ROMIMAGE, "ROM image"},
 	{COFF_OPTMAGIC_PE32, "PE/PE32"},
@@ -45,7 +45,7 @@ int_hash pe_optional_magics[] =
 	{0, 0}
 };
 
-int_hash pe_subsystems[] =
+static int_hash pe_subsystems[] =
 {
 	{0, "generic"},
 	{PE_SUBSYSTEM_NATIVE, "native"},
@@ -53,19 +53,19 @@ int_hash pe_subsystems[] =
 	{PE_SUBSYSTEM_WINDOWS_CUI, "Windows CUI"},
 	{PE_SUBSYSTEM_OS2_CUI, "OS/2 CUI"},
 	{PE_SUBSYSTEM_POSIX_CUI, "POSIX CUI"},
-	{9, "Windows CE GUI"},
-	{10, "EFI"},
-	{11, "EFI/boot"},
-	{12, "EFI/runtime"},
+	{PE_SUBSYSTEM_CE_GUI, "Windows CE GUI"},
+	{PE_SUBSYSTEM_EFI_APPLICATION, "EFI"},
+	{PE_SUBSYSTEM_EFI_BOOT_SERVICE_DRIVER, "EFI/boot"},
+	{PE_SUBSYSTEM_EFI_RUNTIME_DRIVER, "EFI/runtime"},
 	{0, 0}
 };
 
-ht_mask_ptable pemagic[] = {
+static ht_mask_ptable pemagic[] = {
 	{"magic",						STATICTAG_EDIT_DWORD_LE("00000000")},
 	{0, 0}
 };
 
-ht_mask_ptable pe32header[] = {
+static ht_mask_ptable pe32header[] = {
 	{"optional magic",				STATICTAG_EDIT_WORD_LE("00000014")" "STATICTAG_DESC_WORD_LE("00000014", ATOM_PE_OPTIONAL_MAGICS_STR)},
 	{"major linker version",			STATICTAG_EDIT_BYTE("00000016")},
 	{"minor linker version",			STATICTAG_EDIT_BYTE("00000017")},
@@ -78,7 +78,20 @@ ht_mask_ptable pe32header[] = {
 	{0, 0}
 };
 
-ht_mask_ptable pe32header_nt[] = {
+static ht_tag_flags_s pe_dll_characteristics[] =
+{
+	{-1, "PE - dll characteristics"},
+	{0,  "[00] * reserved"},
+	{1,  "[01] * reserved"},
+	{2,  "[02] * reserved"},
+	{3,  "[03] * reserved"},
+	{11,  "[11] do not bind"},
+	{13,  "[13] WDM driver"},
+	{15,  "[15] image is terminal server aware"},
+	{0, 0}
+};
+
+static ht_mask_ptable pe32header_nt[] = {
 	{"image base",					STATICTAG_EDIT_DWORD_LE("00000030")},
 	{"section alignment",			STATICTAG_EDIT_DWORD_LE("00000034")},
 	{"file alignment",				STATICTAG_EDIT_DWORD_LE("00000038")},
@@ -93,7 +106,7 @@ ht_mask_ptable pe32header_nt[] = {
 	{"size of headers",				STATICTAG_EDIT_DWORD_LE("00000050")},
 	{"checksum",					STATICTAG_EDIT_DWORD_LE("00000054")},
 	{"subsystem",					STATICTAG_EDIT_WORD_LE("00000058")" "STATICTAG_DESC_WORD_LE("00000058", ATOM_PE_SUBSYSTEMS_STR)},
-	{"dll characteristics",			STATICTAG_EDIT_WORD_LE("0000005a")},
+	{"dll characteristics",			STATICTAG_EDIT_WORD_LE("0000005a")" "STATICTAG_FLAGS("0000005a", ATOM_PE_DLL_CHARACTERISTICS_STR)},
 	{"stack reserve",				STATICTAG_EDIT_DWORD_LE("0000005c")},
 	{"stack commit",				STATICTAG_EDIT_DWORD_LE("00000060")},
 	{"heap reserve",				STATICTAG_EDIT_DWORD_LE("00000064")},
@@ -103,32 +116,32 @@ ht_mask_ptable pe32header_nt[] = {
 	{0, 0}
 };
 
-ht_mask_ptable pe64header_nt[] = {
-	{"image base",					STATICTAG_EDIT_QWORD_LE("0000002c")},
-	{"section alignment",			STATICTAG_EDIT_DWORD_LE("00000034")},
-	{"file alignment",				STATICTAG_EDIT_DWORD_LE("00000038")},
-	{"major OS version",			STATICTAG_EDIT_WORD_LE("0000003c")},
-	{"minor OS version",			STATICTAG_EDIT_WORD_LE("0000003e")},
-	{"major image version",			STATICTAG_EDIT_WORD_LE("00000040")},
-	{"minor image version",			STATICTAG_EDIT_WORD_LE("00000042")},
-	{"major subsystem version",		STATICTAG_EDIT_WORD_LE("00000044")},
-	{"minor subsystem version",		STATICTAG_EDIT_WORD_LE("00000046")},
-	{"Win32 version",				STATICTAG_EDIT_DWORD_LE("00000048")},
-	{"size of image",				STATICTAG_EDIT_DWORD_LE("0000004c")},
-	{"size of headers",				STATICTAG_EDIT_DWORD_LE("00000050")},
-	{"checksum",					STATICTAG_EDIT_DWORD_LE("00000054")},
-	{"subsystem",					STATICTAG_EDIT_WORD_LE("00000058")" "STATICTAG_DESC_WORD_LE("00000058", ATOM_PE_SUBSYSTEMS_STR)},
-	{"dll characteristics",			STATICTAG_EDIT_WORD_LE("0000005a")},
-	{"stack reserve",				STATICTAG_EDIT_QWORD_LE("0000005c")},
-	{"stack commit",				STATICTAG_EDIT_QWORD_LE("00000064")},
-	{"heap reserve",				STATICTAG_EDIT_QWORD_LE("0000006c")},
-	{"heap commit",				STATICTAG_EDIT_QWORD_LE("00000074")},
-	{"loader flags",				STATICTAG_EDIT_DWORD_LE("0000007c")},
+static ht_mask_ptable pe64header_nt[] = {
+	{"image base",			STATICTAG_EDIT_QWORD_LE("0000002c")},
+	{"section alignment",		STATICTAG_EDIT_DWORD_LE("00000034")},
+	{"file alignment",		STATICTAG_EDIT_DWORD_LE("00000038")},
+	{"major OS version",		STATICTAG_EDIT_WORD_LE("0000003c")},
+	{"minor OS version",		STATICTAG_EDIT_WORD_LE("0000003e")},
+	{"major image version",		STATICTAG_EDIT_WORD_LE("00000040")},
+	{"minor image version",		STATICTAG_EDIT_WORD_LE("00000042")},
+	{"major subsystem version",	STATICTAG_EDIT_WORD_LE("00000044")},
+	{"minor subsystem version",	STATICTAG_EDIT_WORD_LE("00000046")},
+	{"Win32 version",		STATICTAG_EDIT_DWORD_LE("00000048")},
+	{"size of image",		STATICTAG_EDIT_DWORD_LE("0000004c")},
+	{"size of headers",		STATICTAG_EDIT_DWORD_LE("00000050")},
+	{"checksum",			STATICTAG_EDIT_DWORD_LE("00000054")},
+	{"subsystem",			STATICTAG_EDIT_WORD_LE("00000058")" "STATICTAG_DESC_WORD_LE("00000058", ATOM_PE_SUBSYSTEMS_STR)},
+	{"dll characteristics",		STATICTAG_EDIT_WORD_LE("0000005a")},
+	{"stack reserve",		STATICTAG_EDIT_QWORD_LE("0000005c")},
+	{"stack commit",		STATICTAG_EDIT_QWORD_LE("00000064")},
+	{"heap reserve",		STATICTAG_EDIT_QWORD_LE("0000006c")},
+	{"heap commit",			STATICTAG_EDIT_QWORD_LE("00000074")},
+	{"loader flags",		STATICTAG_EDIT_DWORD_LE("0000007c")},
 	{"number of directory entries",	STATICTAG_EDIT_DWORD_LE("00000080")},
 	{0, 0}
 };
 
-ht_mask_ptable pe32header_nt_dirs[] = {
+static ht_mask_ptable pe32header_nt_dirs[] = {
 	{"export directory             (rva/size)", STATICTAG_EDIT_DWORD_LE("00000000")" "STATICTAG_EDIT_DWORD_LE("00000004")" "STATICTAG_REF("0000000000000000", "03", "raw")" "STATICTAG_REF("0000000100000000", "04", "cook")},
 	{"import directory             (rva/size)", STATICTAG_EDIT_DWORD_LE("00000008")" "STATICTAG_EDIT_DWORD_LE("0000000c")" "STATICTAG_REF("0000000000000001", "03", "raw")" "STATICTAG_REF("0000000200000000", "04", "cook")},
 	{"resource directory           (rva/size)", STATICTAG_EDIT_DWORD_LE("00000010")" "STATICTAG_EDIT_DWORD_LE("00000014")" "STATICTAG_REF("0000000000000002", "03", "raw")" "STATICTAG_REF("0000000300000000", "04", "cook")},
@@ -143,12 +156,12 @@ ht_mask_ptable pe32header_nt_dirs[] = {
 	{"bound import directory       (ofs/size)", STATICTAG_EDIT_DWORD_LE("00000058")" "STATICTAG_EDIT_DWORD_LE("0000005c")" "STATICTAG_REF("000000040000000b", "03", "raw")},
 	{"import address table (IAT)   (rva/size)", STATICTAG_EDIT_DWORD_LE("00000060")" "STATICTAG_EDIT_DWORD_LE("00000064")" "STATICTAG_REF("000000000000000c", "03", "raw")},
 	{"delay import descriptor      (rva/size)", STATICTAG_EDIT_DWORD_LE("00000068")" "STATICTAG_EDIT_DWORD_LE("0000006c")" "STATICTAG_REF("000000000000000d", "03", "raw")},
-	{"COM+ runtime header          (rva/size)", STATICTAG_EDIT_DWORD_LE("00000070")" "STATICTAG_EDIT_DWORD_LE("00000074")" "STATICTAG_REF("000000000000000e", "03", "raw")},
+	{"COM+ runtime header          (rva/size)", STATICTAG_EDIT_DWORD_LE("00000070")" "STATICTAG_EDIT_DWORD_LE("00000074")" "STATICTAG_REF("000000000000000e", "03", "raw")" "STATICTAG_REF("0000000f00000000", "04", "cook")},
 	{"reserved (15)                (rva/size)", STATICTAG_EDIT_DWORD_LE("00000078")" "STATICTAG_EDIT_DWORD_LE("0000007c")" "STATICTAG_REF("000000000000000f", "03", "raw")},
 	{0, 0}
 };
 
-ht_view *htpeheader_init(bounds *b, ht_streamfile *file, ht_format_group *group)
+static ht_view *htpeheader_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 {
 	ht_pe_shared_data *pe_shared=(ht_pe_shared_data *)group->get_shared_data();
 
@@ -160,6 +173,7 @@ ht_view *htpeheader_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 	register_atom(ATOM_COFF_SECTION_CHARACTERISTICS, coff_section_characteristics);
 	register_atom(ATOM_PE_OPTIONAL_MAGICS, pe_optional_magics);
 	register_atom(ATOM_PE_SUBSYSTEMS, pe_subsystems);
+	register_atom(ATOM_PE_DLL_CHARACTERISTICS, pe_dll_characteristics);
 
 	ht_mask_sub *s;
 	ht_collapsable_sub *cs;
@@ -167,7 +181,7 @@ ht_view *htpeheader_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 	s=new ht_mask_sub();
 	s->init(file, 0);
 	char info[128];
-	sprintf(info, "* PE header at offset %08x", h);
+	ht_snprintf(info, sizeof info, "* PE header at offset %08x", h);
 	s->add_mask(info);
 	v->insertsub(s);
 
@@ -301,7 +315,7 @@ int ht_pe_header_viewer::ref_sel(LINE_ID *id)
 					hexv->goto_offset(ofs, false);
 					hexv->pselect_set(ofs, ofs+size);
 					app->focus(hexv);
-				} else errorbox("can't follow: %s %08x is not valid !", "directory RVA", rva);
+				} else errorbox("Can't follow: directory RVA %08x is not valid !", rva);
 			}
 			break;
 		}			
@@ -335,16 +349,22 @@ int ht_pe_header_viewer::ref_sel(LINE_ID *id)
 					ofs = pe_shared->pe64.header_nt.directory[id->id2].address;
 					size = pe_shared->pe64.header_nt.directory[id->id2].size;
 				}
-//				if (pe_rva_to_ofs(&pe_shared->sections, ofs, &ofs)) {
+				if (size) {
 					vstate_save();
 					hexv->goto_offset(ofs, false);
 					hexv->pselect_set(ofs, ofs+size);
 					app->focus(hexv);
-//				} else errorbox("can't follow: %s %08x is not valid !", "directory offset", ofs);
+				} else errorbox("can't follow: No bound import directory!", ofs);
+			}
+			break;
+		}
+		case 15: {
+			if (pe_shared->v_il) {
+				vstate_save();
+				app->focus(pe_shared->v_il);
 			}
 			break;
 		}
 	}
 	return 1;
 }
-
