@@ -2,7 +2,7 @@
  *	HT Editor
  *	htpeimp.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -26,10 +26,10 @@
 extern format_viewer_if htpeimports_if;
 
 /*
- *	class ht_pe_import_dlibrary
+ *	class ht_pe_import_library
  */
 
-class ht_pe_import_library: public ht_data {
+class ht_pe_import_library: public Object {
 public:
 	char *name;
 
@@ -41,7 +41,7 @@ public:
  *	class ht_pe_import_function
  */
 
-class ht_pe_import_function: public ht_data {
+class ht_pe_import_function: public Object {
 public:
 	UINT libidx;
 	bool byname;
