@@ -2,7 +2,7 @@
  *	HT Editor
  *	htperes.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -38,7 +38,7 @@
 
 #include <string.h>
 
-int_hash restypes[] = {
+static int_hash restypes[] = {
 	{0x0001, "cursors"},
 	{0x0002, "bitmaps"},
 	{0x0003, "icons"},
@@ -60,7 +60,7 @@ int_hash restypes[] = {
 	{ 0 }
 };
 
-int_hash languages[] = {
+static int_hash languages[] = {
 	{7,  "german"},
 	{9,  "english"},
 	{10, "spanish"},
@@ -69,7 +69,7 @@ int_hash languages[] = {
 	{ 0 }
 };
 
-class ht_pe_resource_leaf: public ht_data {
+class ht_pe_resource_leaf: public Object {
 public:
 	dword offset;
 	dword size;
@@ -81,7 +81,7 @@ static ht_static_treeview *peresource_tree;
 static char peresource_string[128];
 static pe_section_headers *peresource_section_headers;
 
-void read_resource_dir(void *node, int ofs, int level)
+static void read_resource_dir(void *node, int ofs, int level)
 {
 	if (level>2) return; 		/* no deep recursions please (for
 							   currupted resource directories) */
@@ -147,7 +147,7 @@ void read_resource_dir(void *node, int ofs, int level)
 	}
 }
 
-ht_view *htperesources_init(bounds *b, ht_streamfile *file, ht_format_group *group)
+static ht_view *htperesources_init(bounds *b, ht_streamfile *file, ht_format_group *group)
 {
 	ht_pe_shared_data *pe_shared=(ht_pe_shared_data *)group->get_shared_data();
 
@@ -224,18 +224,18 @@ void ht_pe_resource_viewer::done()
 	ht_static_treeview::done();
 }
 
-void	ht_pe_resource_viewer::handlemsg(htmsg *msg)
+void ht_pe_resource_viewer::handlemsg(htmsg *msg)
 {
 	switch (msg->msg) {
 		case msg_vstate_restore:
-			vstate_restore((ht_data*)msg->data1.ptr);
+			vstate_restore((Object*)msg->data1.ptr);
 			clearmsg(msg);
 			return;
 	}
 	ht_static_treeview::handlemsg(msg);
 }
 
-void	ht_pe_resource_viewer::select_node(void *node)
+void ht_pe_resource_viewer::select_node(void *node)
 {
 	static_node *s=(static_node*)node;
 
@@ -261,12 +261,12 @@ void	ht_pe_resource_viewer::select_node(void *node)
 	}
 }
 
-class ht_pe_resource_viewer_vstate: public ht_data {
+class ht_pe_resource_viewer_vstate: public Object {
 public:
 	void *node;
 };
 
-ht_data *ht_pe_resource_viewer::vstate_create()
+Object *ht_pe_resource_viewer::vstate_create()
 {
 	ht_pe_resource_viewer_vstate *v = new ht_pe_resource_viewer_vstate();
 	v->node = get_cursor_node();
@@ -275,7 +275,7 @@ ht_data *ht_pe_resource_viewer::vstate_create()
 
 bool ht_pe_resource_viewer::vstate_save()
 {
-	ht_data *vs = vstate_create();
+	Object *vs = vstate_create();
 	if (vs) {
 		htmsg m;
 		m.msg = msg_vstate_save;
@@ -288,9 +288,8 @@ bool ht_pe_resource_viewer::vstate_save()
 	return false;
 }
 
-void ht_pe_resource_viewer::vstate_restore(ht_data *d)
+void ht_pe_resource_viewer::vstate_restore(Object *d)
 {
 	ht_pe_resource_viewer_vstate *v = new ht_pe_resource_viewer_vstate();
 	goto_node(v->node);
 }
-
