@@ -2,7 +2,7 @@
  *	HT Editor
  *	htperes.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -30,9 +30,9 @@
 class ht_pe_resource_viewer: public ht_static_treeview {
 private:
 /* new */
-	virtual	ht_data *vstate_create();
+	virtual	Object *vstate_create();
 			bool vstate_save();
-	virtual	void vstate_restore(ht_data *d);
+	virtual	void vstate_restore(Object *d);
 public:
 			void init(bounds *b, char *desc);
 	virtual	void done();
