@@ -2,7 +2,7 @@
  *	HT Editor
  *	htreg.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -458,7 +458,7 @@ void ht_registry::debug_dump_i(FILE *f, ht_tree *t, int ident)
 #if 0
 	ht_data_string *key=NULL;
 	ht_registry_node *n;
-	while ((key=(ht_data_string*)t->enum_next((ht_data**)&n, key))) {
+	while ((key=(ht_data_string*)t->enum_next((Object**)&n, key))) {
 		for (int i=0; i<ident; i++) fprintf(f, "     ");
 		fprintf(f, "%s ", key->value);
 		switch (n->type) {
@@ -503,7 +503,7 @@ const char *ht_registry::enum_next(ht_registry_data **data, ht_registry_node_typ
 		ht_data_string ok(prevkey);
 		ht_data_string *k;
 		ht_registry_node *d;
-		if ((k = (ht_data_string*)t->enum_next((ht_data**)&d, prevkey ? &ok : NULL))) {
+		if ((k = (ht_data_string*)t->enum_next((Object**)&d, prevkey ? &ok : NULL))) {
 			*data = d->data;
 			*type = d->type;
 			return k->value;
@@ -524,7 +524,7 @@ const char *ht_registry::enum_prev(ht_registry_data **data, ht_registry_node_typ
 		ht_data_string ok(nextkey);
 		ht_data_string *k;
 		ht_registry_node *d;
-		if ((k = (ht_data_string*)t->enum_prev((ht_data**)&d, nextkey ? &ok : NULL))) {
+		if ((k = (ht_data_string*)t->enum_prev((Object**)&d, nextkey ? &ok : NULL))) {
 			*data = d->data;
 			*type = d->type;
 			return k->value;
@@ -656,7 +656,7 @@ ht_registry_node_type_desc *ht_registry::get_node_type_desc(ht_registry_node_typ
 {
 	ht_data_string *key=NULL;
 	ht_registry_node_type_desc *data;
-	while ((key=(ht_data_string*)node_types->enum_next((ht_data**)&data, key))) {
+	while ((key=(ht_data_string*)node_types->enum_next((Object**)&data, key))) {
 		if (t==data->type) {
 			if (identifier) *identifier = key->value;
 			return data;
@@ -688,7 +688,7 @@ ht_registry_node_type ht_registry::register_node_type(const char *identifier, cr
 		t++;
 		found = true;
 		key = NULL;
-		while ((key=(ht_data_string*)node_types->enum_next((ht_data**)&data, key))) {
+		while ((key=(ht_data_string*)node_types->enum_next((Object**)&data, key))) {
 			if (t == data->type) {
 				found = false;
 				break;
