@@ -2,7 +2,7 @@
  *	HT Editor
  *	htsearch.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -44,7 +44,7 @@ UINT lastreplacemodeid=0;
 
 typedef ht_search_request* (*create_request_func)(search_pos *ret_start, search_pos *ret_end, ht_view *form, ht_format_viewer *format, UINT search_class);
 
-typedef ht_data* (*create_replace_context_func)(ht_streamfile *file, FILEOFS ofs, UINT len, ht_view *form, UINT *return_repllen);
+typedef Object* (*create_replace_context_func)(ht_streamfile *file, FILEOFS ofs, UINT len, ht_view *form, UINT *return_repllen);
 
 struct ht_search_method {
 	char *name;
@@ -477,7 +477,7 @@ ht_search_bin_context::~ht_search_bin_context()
 	free(pat);
 }
 
-ht_data* create_search_bin_context(ht_streamfile *file, FILEOFS ofs, UINT len, byte *pat, UINT patlen, UINT flags, UINT *return_ofs, bool *return_success)
+Object* create_search_bin_context(ht_streamfile *file, FILEOFS ofs, UINT len, byte *pat, UINT patlen, UINT flags, UINT *return_ofs, bool *return_success)
 {
 	if (patlen > SEARCH_BUF_SIZE) return NULL;
 	
@@ -509,7 +509,7 @@ ht_data* create_search_bin_context(ht_streamfile *file, FILEOFS ofs, UINT len, b
 	return ctx;
 }
 
-bool search_bin_process(ht_data *context, ht_text *progress_indicator)
+bool search_bin_process(Object *context, ht_text *progress_indicator)
 {
 	ht_search_bin_context *ctx = (ht_search_bin_context*)context;
 
@@ -884,7 +884,7 @@ ht_view* create_form_replace_hexascii(bounds *b, HT_ATOM histid)
 	return form;
 }
 
-ht_data* create_replace_hexascii_context(ht_streamfile *file, FILEOFS ofs, UINT len, ht_view *form, UINT *return_repllen)
+Object* create_replace_hexascii_context(ht_streamfile *file, FILEOFS ofs, UINT len, ht_view *form, UINT *return_repllen)
 {
 	ht_replace_hexascii_search_form_data d;
 	form->databuf_get(&d, sizeof d);
@@ -1159,7 +1159,7 @@ UINT replace_dialog(ht_format_viewer *format, UINT searchmodes, bool *cancelled)
 					}
 
 					if (replace_all || do_replace) {
-						ht_data *rctx = r->create_replace_context(format->get_file(), result->offset, result->size, rform, &irepllen);
+						Object *rctx = r->create_replace_context(format->get_file(), result->offset, result->size, rform, &irepllen);
 						bool p = execute_process(r->replace_process, rctx);
 						delete rctx;
 						if (!p) {
@@ -1192,7 +1192,7 @@ UINT replace_dialog(ht_format_viewer *format, UINT searchmodes, bool *cancelled)
 }
 
 #define REPLACE_COPY_BUF_SIZE	64*1024
-ht_data* create_replace_bin_context(ht_streamfile *file, FILEOFS ofs, UINT len, byte *repl, UINT repllen, UINT *return_repllen)
+Object* create_replace_bin_context(ht_streamfile *file, FILEOFS ofs, UINT len, byte *repl, UINT repllen, UINT *return_repllen)
 {
 	ht_replace_bin_context *ctx = new ht_replace_bin_context();
 	ctx->file = file;
@@ -1213,7 +1213,7 @@ ht_data* create_replace_bin_context(ht_streamfile *file, FILEOFS ofs, UINT len,
 	return ctx;
 }
 
-bool replace_bin_process(ht_data *context, ht_text *progress_indicator)
+bool replace_bin_process(Object *context, ht_text *progress_indicator)
 {
 	progress_indicator->settext("replacing...\n");
 	
@@ -1514,7 +1514,7 @@ ht_search_result *linear_bin_search(ht_search_request *search, FILEOFS start, FI
 		/* create result */
 		bool search_success = false;
 		FILEOFS search_ofs;
-		ht_data *ctx = create_search_bin_context(file, start, end-start, s->data, s->data_size, fl, &search_ofs, &search_success);
+		Object *ctx = create_search_bin_context(file, start, end-start, s->data, s->data_size, fl, &search_ofs, &search_success);
 		if (execute_process(search_bin_process, ctx)) {
 			delete ctx;
 			if (search_success) {
