@@ -2,7 +2,7 @@
  *	HT Editor
  *	htsearch.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -292,7 +292,7 @@ public:
 ht_search_request *search_dialog(ht_format_viewer *format, UINT searchmodes, viewer_pos *start, viewer_pos *end);
 UINT replace_dialog(ht_format_viewer *format, UINT searchmodes, bool *cancelled);
 
-class ht_search_bin_context: public ht_data {
+class ht_search_bin_context: public Object {
 public:
 	ht_streamfile *file;
 	bool file_end;
@@ -319,8 +319,8 @@ public:
 // flags
 #define SFBIN_CASEINSENSITIVE	1
 
-ht_data* create_search_bin_context(ht_streamfile *file, FILEOFS ofs, UINT len, byte *pat, UINT patlen, UINT flags, UINT *return_ofs, bool *return_success);
-bool search_bin_process(ht_data *context, ht_text *progress_indicator);
+Object* create_search_bin_context(ht_streamfile *file, FILEOFS ofs, UINT len, byte *pat, UINT patlen, UINT flags, UINT *return_ofs, bool *return_success);
+bool search_bin_process(Object *context, ht_text *progress_indicator);
 
 ht_view* create_form_hexascii(bounds *b, HT_ATOM histid);
 void create_desc_hexascii(char *buf, int buflen, ht_view *f);
@@ -331,7 +331,7 @@ ht_search_result *linear_bin_search(ht_search_request *search, FILEOFS start, FI
  *
  */
 
-class ht_replace_bin_context: public ht_data {
+class ht_replace_bin_context: public Object {
 public:
 	ht_streamfile *file;
 
@@ -350,7 +350,7 @@ public:
 	~ht_replace_bin_context();
 };
  
-ht_data* create_replace_bin_context(ht_streamfile *file, FILEOFS ofs, UINT len, byte *repl, UINT repllen, UINT *return_repllen);
-bool replace_bin_process(ht_data *context, ht_text *progress_indicator);
+Object* create_replace_bin_context(ht_streamfile *file, FILEOFS ofs, UINT len, byte *repl, UINT repllen, UINT *return_repllen);
+bool replace_bin_process(Object *context, ht_text *progress_indicator);
 
 #endif /* __HTSEARCH_H__ */
