@@ -2,7 +2,7 @@
  *	HT Editor
  *	htstring.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -395,24 +395,32 @@ bool bnstr(char **str, qword *q, int defaultbase)
 	} else {
 		switch (*(p-1)) {
 			case 'b':
-				base=2;
-				p--;
-				t++;
+				if (base <= 'b'-'a'+10) {
+					base = 2;
+					p--;
+					t++;
+				}
 				break;
 			case 'o':
-				base=8;
-				p--;
-				t++;
+				if (base <= 'o'-'a'+10) {
+					base = 8;
+					p--;
+					t++;
+				}
 				break;
 			case 'd':
-				base=10;
-				p--;
-				t++;
+				if (base <= 'd'-'a'+10) {
+					base = 10;
+					p--;
+					t++;
+				}
 				break;
 			case 'h':
-				base=16;
-				p--;
-				t++;
+				if (base <= 'h'-'a'+10) {
+					base = 16;
+					p--;
+					t++;
+				}
 				break;
 			default:
 				if (**str=='0') base=8;
@@ -447,25 +455,30 @@ int hexdigit(char a)
 	return -1;
 }
 
-dword hexb(char *s)
+bool hexb_ex(uint8 &result, const char *s)
 {
-	byte b=*(byte*)s;
-	b-='0';
-	if (b>9) b-='a'-'0'-10;
-	byte c=*(byte*)(s+1);
-	c-='0';
-	if (c>9) c-='a'-'0'-10;
-	return (b<<4)+c;
+	int v, w;
+	v = hexdigit(s[0]);
+	w = hexdigit(s[1]);
+	if ((v < 0) || (w < 0)) return false;
+	result = (v<<4) | w;
+	return true;
 }
 
-dword hexw(char *s)
+bool hexw_ex(uint16 &result, const char *s)
 {
-	return (hexb(s)<<8) | hexb(s+2);
+	uint8 v, w;
+	if (!hexb_ex(v, s) || !hexb_ex(w, s+2)) return false;
+	result = (v<<8) | w;
+	return true;
 }
 
-dword hexd(char *s)
+bool hexd_ex(uint32 &result, const char *s)
 {
-	return (hexw(s)<<16) | hexw(s+4);
+	uint16 v, w;
+	if (!hexw_ex(v, s) || !hexw_ex(w, s+4)) return false;
+	result = (v<<16) | w;
+	return true;
 }
 
 char *mkhexb(char *buf, byte d)
@@ -578,18 +591,18 @@ void ht_string_list::insert_string(char *s)
  *	CLASS ht_sorted_string_list
  */
  
-void ht_sorted_string_list::init(int (*compare_keys_proc)(ht_data *key_a, ht_data *key_b))
+void ht_sorted_string_list::init(int (*compare_keys_proc)(Object *key_a, Object *key_b))
 {
 	ht_sorted_list::init(compare_keys_proc);
 }
 
 char *ht_sorted_string_list::get_string(char *s)
 {
-	ht_data *d = new ht_data_string(s);
+	Object *d = new ht_data_string(s);
 	UINT i=find(d);
 	char *ret=NULL;
 	if (i!=LIST_UNDEFINED) {
-		ht_data *r=get(i);
+		Object *r=get(i);
 		if (r) ret=((ht_data_string *)r)->value;
 	}
 	delete d;
@@ -605,7 +618,7 @@ void ht_sorted_string_list::insert_string(char *s)
  *	compare_keys_string
  */
 
-int compare_keys_string(ht_data *key_a, ht_data *key_b)
+int compare_keys_string(Object *key_a, Object *key_b)
 {
 	// FIXME:
 	if (((ht_data_string*)key_a)->value && ((ht_data_string*)key_b)->value) {
@@ -617,7 +630,7 @@ int compare_keys_string(ht_data *key_a, ht_data *key_b)
  *	icompare_keys_string
  */
 
-int icompare_keys_string(ht_data *key_a, ht_data *key_b)
+int icompare_keys_string(Object *key_a, Object *key_b)
 {
 	return ht_stricmp(((ht_data_string*)key_a)->value, ((ht_data_string*)key_b)->value);
 }
