@@ -2,7 +2,7 @@
  *	HT Editor
  *	htstring.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -56,9 +56,9 @@ bool bnstr(char **str, qword *q, int defaultbase);
 
 int hexdigit(char a);
 
-dword hexb(char *s);
-dword hexw(char *s);
-dword hexd(char *s);
+bool hexb_ex(uint8 &result, const char *s);
+bool hexw_ex(uint16 &result, const char *s);
+bool hexd_ex(uint32 &result, const char *s);
 
 char *mkhexb(char *buf, byte d);
 char *mkhexw(char *buf, word d);
@@ -69,7 +69,7 @@ char *mkhexq(char *buf, qword q);
  *	CLASS ht_data_string
  */
 
-class ht_data_string: public ht_data {
+class ht_data_string: public Object {
 public:
 	char *value;
 
@@ -100,14 +100,14 @@ public:
 
 class ht_sorted_string_list: public ht_sorted_list {
 public:
-			void init(int (*compare_keys_proc)(ht_data *key_a, ht_data *key_b));
+			void init(int (*compare_keys_proc)(Object *key_a, Object *key_b));
 /* new */
 			char *get_string(char *s);
 			void insert_string(char *s);
 };
 
-int compare_keys_string(ht_data *key_a, ht_data *key_b);
-int icompare_keys_string(ht_data *key_a, ht_data *key_b);
+int compare_keys_string(Object *key_a, Object *key_b);
+int icompare_keys_string(Object *key_a, Object *key_b);
 
 /*
  *	INIT
