@@ -381,7 +381,7 @@ void ht_static_treeview::done()
 	ht_treeview::done();
 }
 
-void *ht_static_treeview::add_child(void *node, char *text, ht_data *Data)
+void *ht_static_treeview::add_child(void *node, char *text, Object *Data)
 {
 	if (node) {
 		return add_node(&((static_node *)node)->child, text, Data);
@@ -395,7 +395,7 @@ void *ht_static_treeview::add_child(void *node, char *text, ht_data *Data)
 	}
 }
 
-void	*ht_static_treeview::add_node(static_node **node, char *text, ht_data *Data)
+void	*ht_static_treeview::add_node(static_node **node, char *text, Object *Data)
 {
 	static_node **p = node;
 	static_node *prev = NULL;
@@ -414,7 +414,7 @@ void	ht_static_treeview::adjust(void *node, bool expand)
 	((static_node *)node)->expanded = expand;
 }
 
-static_node *ht_static_treeview::create_node(char *text, static_node *prev, ht_data *Data)
+static_node *ht_static_treeview::create_node(char *text, static_node *prev, Object *Data)
 {
 	static_node *node = (static_node *)malloc(sizeof(static_node));
 	node->text = ht_strdup(text);
