@@ -2,7 +2,7 @@
  *	HT Editor
  *	infoview.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -29,7 +29,7 @@
 #include "infoview.h"
 #include "tools.h"
 
-class info_pos: public ht_data {
+class info_pos: public Object {
 public:
 	UINT line;
 	UINT ofs;
@@ -40,7 +40,7 @@ public:
 	}
 };
 
-int compare_keys_info_pos_delinear(ht_data *data_a, ht_data *data_b)
+int compare_keys_info_pos_delinear(Object *data_a, Object *data_b)
 {
 	info_pos *a = (info_pos*)data_a;
 	info_pos *b = (info_pos*)data_b;
@@ -52,7 +52,7 @@ int compare_keys_info_pos_delinear(ht_data *data_a, ht_data *data_b)
 	return da - db;
 }
 
-int compare_keys_info_pos(ht_data *data_a, ht_data *data_b)
+int compare_keys_info_pos(Object *data_a, Object *data_b)
 {
 	info_pos *a = (info_pos*)data_a;
 	info_pos *b = (info_pos*)data_b;
@@ -62,7 +62,7 @@ int compare_keys_info_pos(ht_data *data_a, ht_data *data_b)
 	return a->line - b->line;
 }
 
-class info_xref: public ht_data {
+class info_xref: public Object {
 public:
 	char *target;
 	UINT len;
@@ -329,7 +329,7 @@ void ht_info_lexer::set_xrefs(ht_tree *x)
  *	CLASS ht_info_textfile
  */
  
-class info_history_entry: public ht_data {
+class info_history_entry: public Object {
 public:
 	char *cwd;
 	char *file;
@@ -617,7 +617,7 @@ void ht_info_viewer::handlemsg(htmsg *msg)
 					info_xref *x = (info_xref*)get_xrefs()->get(&p);
 					if (!x) {
 						UINT cx = physical_cursorx();
-						info_pos *q = (info_pos*)get_xrefs()->enum_prev((ht_data**)&x, &p);
+						info_pos *q = (info_pos*)get_xrefs()->enum_prev((Object**)&x, &p);
 						if ((q) && ((q->line != top_line+cursory) ||
 						(cx < q->ofs) || (cx >= q->ofs + x->len))) {
 							x = NULL;
@@ -645,7 +645,8 @@ void ht_info_viewer::handlemsg(htmsg *msg)
 					return;
 				}
 				break;
-			case K_BackSpace: {
+			case K_Alt_Backspace:
+			case K_Backspace: {
 				int c;
 				if ((c = history->count())) {
 					info_history_entry *e = (info_history_entry*)history->get(c-1);
@@ -671,7 +672,7 @@ void ht_info_viewer::handlemsg(htmsg *msg)
 				if (get_xrefs()) {
 					info_pos p(top_line + cursory, xofs + physical_cursorx());
 					info_xref *r;
-					info_pos *q = (info_pos*)get_xrefs()->enum_next((ht_data**)&r, &p);
+					info_pos *q = (info_pos*)get_xrefs()->enum_next((Object**)&r, &p);
 					if (q) {
 						goto_line(q->line);
 						cursor_pput(q->ofs);
@@ -685,7 +686,7 @@ void ht_info_viewer::handlemsg(htmsg *msg)
 				if (get_xrefs()) {
 					info_pos p(top_line + cursory, xofs + physical_cursorx());
 					info_xref *r;
-					info_pos *q = (info_pos*)get_xrefs()->enum_prev((ht_data**)&r, &p);
+					info_pos *q = (info_pos*)get_xrefs()->enum_prev((Object**)&r, &p);
 					if (q) {
 						goto_line(q->line);
 						cursor_pput(q->ofs);
