@@ -2,7 +2,7 @@
  *	HT Editor
  *	infoview.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -30,7 +30,7 @@
  *	CLASS info_node
  */
 
-class info_node: public ht_data {
+class info_node: public Object {
 public:
 	FILEOFS start;
 	UINT len;
