@@ -2,7 +2,7 @@
  *	HT Editor
  *	io.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -236,7 +236,7 @@ K_FIRST = 0,
 
 /* ASCII > 0 */
 
-K_BackSpace		= 1,
+K_Backspace		= 1,
 K_BackTab			= 2,
 
 K_Tab			= '\t',
