@@ -58,7 +58,7 @@ ht_key_keycode ht_win32_key_defs[] = {
 	{K_Control_E,			(0x005+HT_VK_CTRL)},
 	{K_Control_F,			(0x006+HT_VK_CTRL)},
 	{K_Control_G,			(0x007+HT_VK_CTRL)},
-	{K_BackSpace,			0x008},
+	{K_Backspace,			0x008},
 	{K_Control_H,			(0x008+HT_VK_CTRL)},
 	{K_Tab,				0x009},
 	{K_Control_I,			(0x009+HT_VK_CTRL)},
@@ -86,11 +86,11 @@ ht_key_keycode ht_win32_key_defs[] = {
 //	{K_Control_RBracket,	0x01d},
 //	{K_Control_Caret,		0x01e},
 //	{K_Control_Underscore,	0x01f},
-//	{K_Control_Backspace,	(K_BackSpace+HT_VK_CTRL)},
+//	{K_Control_Backspace,	(K_Backspace+HT_VK_CTRL)},
 
 	{K_Alt_Escape,			(K_Escape+HT_VK_ALT)},
 //	{K_Control_At,			0x103},
-	{K_Alt_Backspace,		(K_BackSpace+HT_VK_ALT)},
+	{K_Alt_Backspace,		(K_Backspace+HT_VK_ALT)},
 	{K_BackTab,			HT_VK_SHIFT+0x0009},
 	{K_Alt_Q,				('q'+HT_VK_ALT)},
 	{K_Alt_W,				('w'+HT_VK_ALT)},
