@@ -2,8 +2,8 @@
  *	HT Editor
  *	htsys.cc (WIN32 implementation)
  *
- *	Copyright (C) 1999-2002 Sebastian Biallas (sb@web-productions.de)
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Sebastian Biallas (sb@biallas.net)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -21,6 +21,7 @@
 
 #include "htsys.h"
 #include "qword.h"
+#include "snprintf.h"
 
 #include <ctype.h>
 #include <errno.h>
@@ -128,24 +129,24 @@ int sys_pstat(pstat_t *s, const char *filename)
 	int flen = strlen(fn);
 	if (flen && sys_is_path_delim(fn[flen-1]) && (flen !=3) || (fn[1]!=':')) fn[flen-1] = 0;
 	struct stat st;
-	int e=stat(fn, &st);
+	int e = stat(fn, &st);
 	if (e) return ENOENT;
-	s->caps=pstat_ctime|pstat_mtime|pstat_atime|pstat_uid|pstat_gid|pstat_mode_all|pstat_size|pstat_inode;
-	s->ctime=st.st_ctime;
-	s->mtime=st.st_mtime;
-	s->atime=st.st_atime;
-	s->gid=st.st_uid;
-	s->uid=st.st_gid;
-	s->mode=sys_ht_mode(st.st_mode);
-	s->size=st.st_size;
-	s->size_high=0;
-	s->fsid=st.st_ino;
+	s->caps = pstat_ctime|pstat_mtime|pstat_atime|pstat_uid|pstat_gid|pstat_mode_all|pstat_size|pstat_inode;
+	s->ctime = st.st_ctime;
+	s->mtime = st.st_mtime;
+	s->atime = st.st_atime;
+	s->gid = st.st_uid;
+	s->uid = st.st_gid;
+	s->mode = sys_ht_mode(st.st_mode);
+	s->size = st.st_size;
+	s->size_high = 0;
+	s->fsid = st.st_ino;
 	return 0;
 }
 
 void sys_suspend()
 {
-	Sleep(0);
+	Sleep(42);
 }
 
 int sys_get_free_mem()
@@ -339,6 +340,49 @@ int sys_get_caps()
 	return SYSCAP_NONBLOCKING_IPC;
 }
 
+bool sys_write_data_to_native_clipboard(const void *data, int size)
+{
+	if (!OpenClipboard(NULL)) return false;
+	HANDLE h = GlobalAlloc(GMEM_MOVEABLE | GMEM_DDESHARE, size);
+	if (!h) {
+		CloseClipboard();
+		return false;
+	}
+	void *mem = GlobalLock(h);
+	memmove(mem, data, size);
+	GlobalUnlock(h);
+	SetClipboardData(CF_OEMTEXT, h);
+	CloseClipboard();
+}
+
+int sys_get_native_clipboard_data_size()
+{
+	if (!OpenClipboard(NULL)) return false;
+	HANDLE h = GetClipboardData(CF_OEMTEXT);
+	int len = 0;
+	if (h) {
+		void *mem = GlobalLock(h);
+		len = strlen((char*)mem);
+		GlobalUnlock(h);		
+	}
+	CloseClipboard();
+	return len;
+}
+
+bool sys_read_data_from_native_clipboard(void *data, int max_size)
+{
+	if (!OpenClipboard(NULL)) return false;
+	HANDLE h = GetClipboardData(CF_OEMTEXT);
+	if (h) {
+		void *mem = GlobalLock(h);
+		ht_snprintf((char*)data, max_size, "%s", mem);
+		GlobalUnlock(h);		
+	}
+	CloseClipboard();
+	return h != NULL;
+}
+
+
 /*
  *	INIT
  */
