@@ -2,7 +2,7 @@
  *	HT Editor
  *	mfile.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -60,7 +60,7 @@ UINT ht_mod_page::write(PAGEOFS pofs, const byte *buf, UINT len)
  *	CLASS ht_streamfile_modifier
  */
 
-int compare_keys_file_delinear(ht_data *key_a, ht_data *key_b)
+int compare_keys_file_delinear(Object *key_a, Object *key_b)
 {
 	FILEOFS a = (FILEOFS)delinearize((dword)((ht_data_uint*)key_a)->value);
 	FILEOFS b = (FILEOFS)delinearize((dword)((ht_data_uint*)key_b)->value);
@@ -159,7 +159,7 @@ void ht_streamfile_modifier::mod_pages_destroy()
 void ht_streamfile_modifier::mod_pages_flush()
 {
 	ht_data_uint *key=NULL;
-	ht_data *value;
+	Object *value;
 
 	while ((key=(ht_data_uint*)mod_pages->enum_next(&value, key))) {
 		mod_page_flush(key->value);
