@@ -2,7 +2,7 @@
  *	HT Editor
  *	mfile.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -32,7 +32,7 @@ typedef FILEOFS PAGEOFS;
 
 #define DEFAULT_MOD_PAGE_SIZE 8*1024	/* MUST BE 2^n */
 
-class ht_mod_page: public ht_data {
+class ht_mod_page: public Object {
 public:
 	UINT size;
 	byte *data;
