@@ -38,7 +38,7 @@
 //#define DPRINTF(msg...) printf(##msg)
 //#define DPRINTF2(msg...) printf(##msg)
 
-int compare_keys_addresses_delinear(ht_data *key_a, ht_data *key_b)
+int compare_keys_addresses_delinear(Object *key_a, Object *key_b)
 {
 	return ((Address*)key_a)->compareDelinear((Address*)key_b);
 }
@@ -274,7 +274,7 @@ void AnalyserOutput::generateAddr(Address *Addr, OutAddr *oa)
 				if (x_tree) {
 					int i=0;
 					AddrXRef *x;
-					Address *xa = (Address*)x_tree->enum_next((ht_data**)&x, NULL);
+					Address *xa = (Address*)x_tree->enum_next((Object**)&x, NULL);
 					while (xa) {
 						if ((i % (MAX_XREF_COLS+1))!=0) {
 							char buf3[90];
@@ -282,7 +282,7 @@ void AnalyserOutput::generateAddr(Address *Addr, OutAddr *oa)
 							write(buf3);
 							xa->stringify(buf3, 1024, ADDRESS_STRING_FORMAT_COMPACT);
 							write(link(buf3, xa));
-							xa = (Address*)x_tree->enum_next((ht_data**)&x, xa);
+							xa = (Address*)x_tree->enum_next((Object**)&x, xa);
 						} else {
 							if (i!=0) {
 								endLine();
@@ -522,9 +522,9 @@ void	AnalyserOutput::generatePage(Address *from, int lines)
 
 OutAddr *AnalyserOutput::getAddr(Address *Addr)
 {
-			char tbuf[1024];
-			Addr->stringify(tbuf, 1024, 0);
-			DPRINTF("%s -- ",tbuf);
+	char tbuf[1024];
+	Addr->stringify(tbuf, 1024, 0);
+	DPRINTF("%s -- ",tbuf);
 	if (!addr->isValid() || Addr->compareTo(addr) != 0) {
 		assert(addr != Addr);
 		DPRINTF("not cached1 --");
@@ -652,13 +652,10 @@ int	AnalyserOutput::nextLine(Address *&Addr, int &line, int n, Address *max)
 int	AnalyserOutput::prevLine(Address *&Addr, int &line, int n, Address *min)
 {
 //	fprintf(stdout, "prev_line(%x, %d, %d)\n", *Addr, *line, n);
-#define ADDRBUF(a)
-//#define ADDRBUF(a) (a)->stringify(tbuf, 1024, 0);
+//#undef DPRINTF2
+//#define DPRINTF2(msg...) {ht_snprintf(tbuf, 1024, ##msg); fprintf(stderr, "%s", tbuf);}
 //	char tbuf[1024];
-	ADDRBUF(*Addr)
-	DPRINTF2("prev_line(%s, %d, %d", tbuf, *line, n);
-	ADDRBUF(min)
-	DPRINTF2(", %s)\n", tbuf);
+	DPRINTF2("prev_line(%y, %d, %d, %y)\n", Addr, line, n, min);
 
 	int res = 0;
 	int cmp = Addr->compareTo(min);
@@ -716,7 +713,7 @@ int	AnalyserOutput::prevLine(Address *&Addr, int &line, int n, Address *min)
 
 	/*
 	 *	|prev| contains the previous "logical" location.
-	 *	that is some address, we know to be "atomic".
+	 *	That is some address known to be "atomic".
 	 */
 	Location *prev = analy->enumLocationsReverse(Addr);
 	if (prev) {
@@ -726,7 +723,7 @@ int	AnalyserOutput::prevLine(Address *&Addr, int &line, int n, Address *min)
 		 */
 		Address *prevnext = DUP_ADDR(prev->addr);
 		if (prevnext->add(getAddrByteLength(prev->addr))) {
-				DPRINTF2("mid-test\n");
+			DPRINTF2("mid-test\n");
 			if (prevnext->compareTo(Addr) > 0) {
 				/*
 				 *   We were in the middle of a location.
@@ -752,10 +749,13 @@ int	AnalyserOutput::prevLine(Address *&Addr, int &line, int n, Address *min)
 				DPRINTF2("mid2\n");
 				return prevLine(Addr, line, n-1, min)+res;
 			}
+			DPRINTF2("prev: %y prevnext: %y search_addr: %y\n", prev->addr, prevnext, search_addr);
 			Address *oldprevnext = DUP_ADDR(prevnext);
 			if (prevnext->add(l) && prevnext->compareTo(Addr) >= 0) {
 				delete search_addr;
 				search_addr = oldprevnext;
+				DPRINTF2("prevnext: %y Addr: %y\n", prevnext, Addr);
+				DPRINTF2("search_addr: %y\n", search_addr);
 				DPRINTF2("mid3\n");
 			} else {
 				delete oldprevnext;
@@ -778,13 +778,11 @@ int	AnalyserOutput::prevLine(Address *&Addr, int &line, int n, Address *min)
 	int linebuf[1024];
 	int i = 0;
 	int len;
-	
+
 	Address *next_addr = DUP_ADDR(search_addr);
 	while (1) {
-		ADDRBUF(search_addr);
-		DPRINTF2("search_addr: (%s, %d) ", tbuf, search_line);
-		ADDRBUF(next_addr);
-		DPRINTF2("next_addr: %s \n", tbuf);
+		DPRINTF2("search_addr: (%y, %d) ", search_addr, search_line);
+		DPRINTF2("next_addr: %y \n", next_addr);
 		if (search_addr->compareTo(Addr) >= 0) {
 			if (search_line >= line || (search_addr->compareTo(Addr) > 0)) break;
 		}
