@@ -2,7 +2,7 @@
  *	HT Editor
  *	process.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -24,7 +24,7 @@
 #include "htiobox.h"
 #include "htkeyb.h"
 
-bool execute_process(process_func pp, ht_data *context)
+bool execute_process(process_func pp, Object *context)
 {
 	bounds b;
 	get_std_progress_indicator_metrics(&b);
@@ -53,7 +53,7 @@ bool execute_process(process_func pp, ht_data *context)
 	return !cancelled;
 }
 
-void execute_process_bg(process_func pp, ht_data *context)
+void execute_process_bg(process_func pp, Object *context)
 {
 	/* FIXME: nyi */
 }
