@@ -2,7 +2,7 @@
  *	HT Editor
  *	process.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -25,8 +25,8 @@
 #include "htdata.h"
 #include "htobj.h"
 
-typedef bool (*process_func)(ht_data *context, ht_text *progress_indicator);
+typedef bool (*process_func)(Object *context, ht_text *progress_indicator);
 
-bool execute_process(process_func pp, ht_data *context);
+bool execute_process(process_func pp, Object *context);
 
 #endif /* __PROCESS_H__ */
