@@ -2,7 +2,7 @@
  *	HT Editor
  *	srt.h
  *
- *	Copyright (C) 2001, 2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 2001, 2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -34,7 +34,7 @@ enum srt_endian { srte_be, srte_le };
 #define MTYPE_FLAG		1
 #define MTYPE_MEM		2
 
-class state_mod: public ht_data {
+class state_mod: public Object {
 public:
 	bool ismem;
 	union {
