@@ -2,7 +2,7 @@
  *	HT Editor
  *	srt_x86.cc
  *
- *	Copyright (C) 2001, 2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 2001, 2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -60,13 +60,13 @@ void srt_x86_setreg(CPU *cpu, UINT idx, Object *o)
 		k = &cpu->flags[(idx-8) % X86_FLAGS];
 		(*k)->done();
 		delete *k;
-		((Object*)*k) = o;
+		*k = (sym_bool *)o;
 	} else {
 		sym_int **k;
 		k = &cpu->regs[idx & 7];
 		(*k)->done();
 		delete *k;
-		((Object*)*k) = o;
+		*k = (sym_int *)o;
 	}
 }
 
