@@ -2,7 +2,7 @@
  *	HT Editor
  *	symmath.cc
  *
- *	Copyright (C) 2001, 2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 2001, 2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -174,7 +174,7 @@ OBJECT_ID sym_int_const::object_id() const
  *	CLASS sym_int_token_rec
  */
  
-class sym_int_token_rec: public ht_data {
+class sym_int_token_rec: public Object {
 public:
 	u_op uop;
 	b_op bop;
@@ -858,7 +858,7 @@ void sym_bool_intcmp::simplify()
  *	CLASS sym_bool_token_rec
  */
  
-class sym_bool_token_rec: public ht_data {
+class sym_bool_token_rec: public Object {
 public:
 	n_op nop;
 	l_op lop;
