@@ -2,7 +2,7 @@
  *	HT Editor
  *	symmath.h
  *
- *	Copyright (C) 2001, 2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 2001, 2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -80,7 +80,7 @@ extern b_op *c_op_prec[];
  *	CLASS sym_int_token
  */
 
-class sym_int_token: public ht_data {
+class sym_int_token: public Object {
 public:
 /* new */
 	virtual bool compare_eq(sym_int_token *t)=0;
@@ -159,7 +159,7 @@ public:
  *	CLASS sym_bool_token
  */
 
-class sym_bool_token: public ht_data {
+class sym_bool_token: public Object {
 public:
 /* new */
 	virtual bool compare_eq(sym_bool_token *t)=0;
