@@ -278,7 +278,7 @@ qword ht_object_stream_txt::getQWordHex(int size, char *desc)
 	readDesc(desc);
 	expect('=');
 	skipWhite();
-	if (mapchar[cur]!='0') setSyntaxError();
+	if (mapchar[(unsigned char)cur]!='0') setSyntaxError();
 	char str[40];
 	char *s=str;
 	do {
@@ -286,7 +286,7 @@ qword ht_object_stream_txt::getQWordHex(int size, char *desc)
 		if (s-str >= 39) setSyntaxError();
 		readChar();
 		if (get_error()) return to_qword(0);
-	} while (mapchar[cur]=='0' || mapchar[cur]=='A');
+	} while (mapchar[(unsigned char)cur]=='0' || mapchar[(unsigned char)cur]=='A');
 	*s=0; s=str;
 	qword a;
 	if (!bnstr(&s, &a, 10)) setSyntaxError();
@@ -480,7 +480,7 @@ void	ht_object_stream_txt::expect(char c)
 void	ht_object_stream_txt::skipWhite()
 {
 	while (1) {
-		switch (mapchar[cur]) {
+		switch (mapchar[(unsigned char)cur]) {
 			case '\n':
 				line++;  // fallthrough
 			case ' ':
