@@ -2,7 +2,7 @@
  *	HT Editor
  *	stream.cc
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -431,7 +431,7 @@ int ht_sys_file::extend(UINT newsize)
 	char buf[EXTEND_BUFSIZE];
 	memset(buf, 0, sizeof buf);
 	newsize-=s;
-	seek(s);
+	if ((r = seek(s))) return r;
 	while (newsize) {
 		UINT k=MIN(sizeof buf, newsize);
 		UINT l=write(buf, k);
@@ -519,7 +519,7 @@ int ht_stdio_file::extend(UINT newsize)
 	char buf[EXTEND_BUFSIZE];
 	memset(buf, 0, sizeof buf);
 	newsize-=s;
-	seek(s);
+	if ((r = seek(s))) return r;
 	while (newsize) {
 		UINT k=MIN(sizeof buf, newsize);
 		UINT l=write(buf, k);
@@ -639,7 +639,7 @@ RETRY:
 		if (am & FAM_READ) mode = "rb";
 		if (am & FAM_WRITE) mode = "rb+";
 	}
-	
+
 	bool retval = true;
 	if (am != FAM_NULL) {
 		int e = 0;
@@ -865,14 +865,14 @@ void ht_mem_file::init()
 void ht_mem_file::init(FILEOFS o, UINT size, UINT am)
 {
 	ht_streamfile::init();
-	ofs=o;
-	buf=(byte*)malloc(size ? size : 1);
-	ibufsize=size;
-	bufsize=size;
+	ofs = o;
+	buf = (byte*)malloc(size ? size : 1);
+	ibufsize = size;
+	bufsize = size;
 	memset(buf, 0, size);
-	pos=0;
-	dsize=0;
-	access_mode=0;
+	pos = 0;
+	dsize = 0;
+	access_mode = 0;
 	if (!set_access_mode(am)) throw new ht_io_exception("unable to open memfile");
 }
 
@@ -890,7 +890,7 @@ void *ht_mem_file::bufptr()
 int ht_mem_file::extend(UINT newsize)
 {
 	while (bufsize<newsize) extendbuf();
-	dsize=newsize;
+	dsize = newsize;
 	return 0;
 }
 
@@ -1009,7 +1009,7 @@ UINT ht_mem_file::write(const void *b, UINT size)
 char *fgetstrz(ht_streamfile *file)
 {
 	FILEOFS o=file->tell();
-/* get string size */
+	/* get string size */
 	char buf[64];
 	int s, z=0;
 	int found=0;
@@ -1023,7 +1023,7 @@ char *fgetstrz(ht_streamfile *file)
 			}
 		}
 	}
-/* read string */
+	/* read string */
 	char *str=(char *)malloc(z);
 	file->seek(o);
 	file->read(str, z);
@@ -1035,7 +1035,7 @@ char *fgetstrz(ht_streamfile *file)
  
 char *getstrz(ht_stream *stream)
 {
-/* get string size */
+	/* get string size */
 	char buf[REASONABLE_STRING_LIMIT];
 	int s, z=0;
 	while (1) {
@@ -1082,7 +1082,7 @@ char *getstrw(ht_stream *stream)
 	byte lbuf[2];
 	stream->read(lbuf, 2);
 	int l = lbuf[0] | lbuf[1] << 8;
-	char	*a=(char*)malloc(l+1);
+	char *a=(char*)malloc(l+1);
 	for (int i=0; i<l; i++) {
 		stream->read(&t, 2);
 		*(a+i)=(char)t;
