@@ -2,8 +2,8 @@
  *	HT Editor
  *	textedit.cc
  *
- *	Copyright (C) 1999-2002 Sebastian Biallas (sb@web-productions.de)
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Sebastian Biallas (sb@biallas.net)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -2276,7 +2276,7 @@ void ht_text_editor::handlemsg(htmsg *msg)
 					clearmsg(msg);
 					return;
 				}
-				case K_BackSpace: {
+				case K_Backspace: {
 					UINT cx=physical_cursorx();
 					if (cx) {
 						if (cx <= textfile->getlinelength(top_line+cursory)) {
