@@ -2,8 +2,8 @@
  *	HT Editor
  *	textedit.h
  *
- *	Copyright (C) 1999-2002 Sebastian Biallas (sb@web-productions.de)
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Sebastian Biallas (sb@biallas.net)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -54,7 +54,7 @@ class ht_text_editor;
 /*
  *	CLASS ht_undo_data
  */
-class ht_undo_data: public ht_data {
+class ht_undo_data: public Object {
 public:
 	ht_undo_data();
 	virtual bool combine(ht_undo_data *ud);
