@@ -2,7 +2,7 @@
  *	HT Editor
  *	textfile.h
  *
- *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
+ *	Copyright (C) 1999-2002 Stefan Weyergraf
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License version 2 as
@@ -74,7 +74,7 @@ public:
  *	CLASS ht_ltextfile_line
  */
 
-class ht_ltextfile_line: public ht_data {
+class ht_ltextfile_line: public Object {
 public:
 	virtual ~ht_ltextfile_line();
 
