@@ -31,7 +31,7 @@ dword delinearize(dword d)
 	return d*0x8088405+1;	/* there's magic in here... */
 }
 
-int compare_keys_int_delinear(ht_data *key_a, ht_data *key_b)
+int compare_keys_int_delinear(Object *key_a, Object *key_b)
 {
 	int a = delinearize(((ht_data_uint*)key_a)->value);
 	int b = delinearize(((ht_data_uint*)key_b)->value);
@@ -39,7 +39,7 @@ int compare_keys_int_delinear(ht_data *key_a, ht_data *key_b)
 	return 0;
 }
 
-int compare_keys_uint_delinear(ht_data *key_a, ht_data *key_b)
+int compare_keys_uint_delinear(Object *key_a, Object *key_b)
 {
 	UINT a = delinearize(((ht_data_uint*)key_a)->value);
 	UINT b = delinearize(((ht_data_uint*)key_b)->value);
