@@ -43,8 +43,8 @@
 
 dword delinearize(dword d);
 
-int compare_keys_int_delinear(ht_data *key_a, ht_data *key_b);
-int compare_keys_uint_delinear(ht_data *key_a, ht_data *key_b);
+int compare_keys_int_delinear(Object *key_a, Object *key_b);
+int compare_keys_uint_delinear(Object *key_a, Object *key_b);
 
 int *random_permutation(int max);
 
